@@ -590,7 +590,8 @@ void DerivativeOfWindowFunc(int whichFunction, size_t NumSamples, bool extraSamp
       // Hamming
       // There are deltas at the ends
       const double multiplier = 2 * M_PI / NumSamples;
-      static const double coeff0 = 0.54, coeff1 = -0.46 * multiplier;
+      static const double coeff0 = 0.54;
+      const double coeff1 = -0.46 * multiplier;
       // TODO This code should be more explicit about the precision it intends.
       // For now we get C4305 warnings, truncation from 'const double' to 'float' 
       in[0] *= coeff0;
