@@ -16,12 +16,12 @@
 class NiceAudioSegment final : public AudioSegment
 {
 public:
-   size_t GetFloats(float *const *, size_t numSamples) override
+   size_t GetFloats(float* const*, size_t numSamples) override
    {
       return numSamples;
    }
 
-   size_t GetWidth() const override
+   size_t NChannels() const override
    {
       return 1u;
    }
@@ -36,7 +36,7 @@ class MockAudioSegmentFactory : public AudioSegmentFactoryInterface
 {
 public:
    std::vector<std::shared_ptr<AudioSegment>>
-   CreateAudioSegmentSequence(double, PlaybackDirection) const override
+   CreateAudioSegmentSequence(double, PlaybackDirection) override
    {
       ++const_cast<size_t&>(callCount);
       return { std::make_shared<NiceAudioSegment>() };
