@@ -11,11 +11,4 @@
 #include "ModuleConstants.h"
 
 // We want Audacity with a capital 'A'
-// DA: App name
-const std::wstring AppName =
-#ifndef EXPERIMENTAL_DA
-   L"Audacity"
-#else
-   L"DarkAudacity"
-#endif
-;
+const std::wstring AppName = L"Audacity";
