@@ -129,16 +129,17 @@ class PipeClient():
 
     _shared_state = {}
 
-    def __new__(cls, *p, **k):
+    def __new__(cls, enc='', *p, **k):
         self = object.__new__(cls, *p, **k)
         self.__dict__ = cls._shared_state
         return self
 
-    def __init__(self):
+    def __init__(self, enc=''):
         self.timer = False
         self._start_time = 0
         self._write_pipe = None
         self.reply = ''
+        self.enc = enc
         if not self._write_pipe:
             self._write_thread_start()
         self._read_thread_start()
@@ -157,7 +158,11 @@ class PipeClient():
 
     def _write_pipe_open(self):
         """Open _write_pipe."""
-        self._write_pipe = open(WRITE_NAME, 'w')
+        if self.enc:
+            self._write_pipe = open(WRITE_NAME, 'w', newline='',
+                                    encoding=self.enc)
+        else:
+            self._write_pipe = open(WRITE_NAME, 'w', newline='')
 
     def _read_thread_start(self):
         """Start read_pipe thread."""
@@ -202,7 +207,11 @@ class PipeClient():
         """Read FIFO in worker thread."""
         # Thread will wait at this read until it connects.
         # Connection should occur as soon as _write_pipe has connected.
-        read_pipe = open(READ_NAME, 'r')
+        read_pipe = None
+        if self.enc:
+            read_pipe = open(READ_NAME, 'r', newline='', encoding=self.enc)
+        else:
+            read_pipe = open(READ_NAME, 'r', newline='')
         message = ''
         pipe_ok = True
         while pipe_ok:
@@ -262,20 +271,21 @@ def main():
                         help='show command execution time (default: True)')
     parser.add_argument('-d', '--docs', action='store_true',
                         help='show documentation and exit')
+    parser.add_argument('-e', '--pipe-encoding', type=str, default='',
+                        help='non-default encoding to use for r/w pipes')
     args = parser.parse_args()
 
     if args.docs:
         print(__doc__)
         sys.exit(0)
 
-    client = PipeClient()
+    client = PipeClient(enc=args.pipe_encoding)
     while True:
         reply = ''
         if sys.version_info[0] < 3:
-            message = input("\nEnter command or 'Q' to quit: ")
+            message = raw_input("\nEnter command or 'Q' to quit: ")
         else:
-            message = input(
-                "\nEnter command or 'Q' to quit: ")
+            message = input("\nEnter command or 'Q' to quit: ")
         start = time.time()
         if message.upper() == 'Q':
             sys.exit(0)
