@@ -10,46 +10,49 @@
 ********************************************************************//*!
 
 \class MacroCommands
-\brief Maintains the list of commands for batch/macro 
+\brief Maintains the list of commands for batch/macro
 processing.  See also MacrosWindow and ApplyMacroDialog.
 
 *//*******************************************************************/
-
 #define wxLOG_COMPONENT "MacroCommands"
 
-
 #include "BatchCommands.h"
+#include "DoEffect.h"
+#include "EffectAndCommandPluginManager.h"
 
-#include <wx/defs.h>
 #include <wx/datetime.h>
+#include <wx/defs.h>
 #include <wx/dir.h>
+#include <wx/frame.h>
 #include <wx/log.h>
 #include <wx/textfile.h>
 #include <wx/time.h>
 
+#include "Effect.h"
+#include "EffectManager.h"
+#include "FileNames.h"
+#include "PluginManager.h"
+#include "Prefs.h"
 #include "Project.h"
 #include "ProjectHistory.h"
 #include "ProjectSettings.h"
-#include "ProjectWindow.h"
-#include "commands/CommandManager.h"
-#include "effects/EffectManager.h"
-#include "effects/EffectUI.h"
-#include "FileNames.h"
-#include "Menus.h"
-#include "PluginManager.h"
-#include "Prefs.h"
+#include "ProjectWindows.h"
 #include "SelectFile.h"
 #include "SelectUtilities.h"
 #include "SettingsVisitor.h"
 #include "Track.h"
 #include "UndoManager.h"
+#include "effects/EffectPresetDialog.h"
+#include "effects/EffectUI.h"
+#include "effects/EffectUIServices.h"
 
 #include "AllThemeResources.h"
 
 #include "AudacityMessageBox.h"
 
-#include "commands/CommandContext.h"
+#include "CommandContext.h"
 #include "commands/CommandDispatch.h"
+#include "CommandManager.h"
 
 MacroCommands::MacroCommands( AudacityProject &project )
 : mProject{ project }
@@ -307,11 +310,11 @@ MacroCommandsCatalog::MacroCommandsCatalog( const AudacityProject *project )
    Entries commands;
 
    PluginManager & pm = PluginManager::Get();
-   EffectManager & em = EffectManager::Get();
+   EffectManager& em = EffectManager::Get();
    {
       for (auto &plug
            : pm.PluginsOfType(PluginTypeEffect|PluginTypeAudacityCommand)) {
-         auto command = em.GetCommandIdentifier(plug.GetID());
+         auto command = pm.GetCommandIdentifier(plug.GetID());
          if (!command.empty())
             commands.push_back( {
                { command, plug.GetSymbol().Msgid() },
@@ -342,7 +345,7 @@ MacroCommandsCatalog::MacroCommandsCatalog( const AudacityProject *project )
          else {
             // We'll disambiguate if the squashed name is short and shorter than the internal name.
             // Otherwise not.
-            // This means we won't have repetitive items like "Cut (Cut)" 
+            // This means we won't have repetitive items like "Cut (Cut)"
             // But we will show important disambiguation like "All (SelectAll)" and "By Date (SortByDate)"
             // Disambiguation is no longer essential as the details box will show it.
             // PRL:  I think this reasoning applies only when locale is English.
@@ -431,44 +434,81 @@ auto MacroCommandsCatalog::ByCommandId( const CommandID &commandId ) const
          { return entry.name.Internal() == commandId; });
 }
 
+// linear search
+auto MacroCommandsCatalog::ByTranslation(const wxString &translation) const
+   -> Entries::const_iterator
+{
+   return std::find_if(begin(), end(),
+      [&](const Entry& entry)
+      { return entry.name.Translation() == translation; });
+}
+
 wxString MacroCommands::GetCurrentParamsFor(const CommandID & command)
 {
-   const PluginID & ID =
-      EffectManager::Get().GetEffectByIdentifier(command);
+   const PluginID& ID = PluginManager::Get().GetByCommandIdentifier(command);
    if (ID.empty())
    {
       return wxEmptyString;   // effect not found.
    }
 
-   return EffectManager::Get().GetEffectParameters(ID);
+   return EffectAndCommandPluginManager::Get().GetEffectParameters(ID);
 }
 
 wxString MacroCommands::PromptForParamsFor(
-   const CommandID & command, const wxString & params, wxWindow &parent)
+   const CommandID& command, const wxString& params, AudacityProject& project)
 {
-   const PluginID & ID =
-      EffectManager::Get().GetEffectByIdentifier(command);
+   const PluginID& ID = PluginManager::Get().GetByCommandIdentifier(command);
    if (ID.empty())
       return wxEmptyString;   // effect not found
 
    wxString res = params;
-   auto cleanup = EffectManager::Get().SetBatchProcessing(ID);
-   if (EffectManager::Get().SetEffectParameters(ID, params))
-      if (EffectManager::Get().PromptUser(ID, EffectUI::DialogFactory, parent))
-         res = EffectManager::Get().GetEffectParameters(ID);
+   auto cleanup = EffectAndCommandPluginManager::Get().SetBatchProcessing(ID);
+   if (EffectAndCommandPluginManager::Get().SetEffectParameters(ID, params))
+   {
+      auto dialogInvoker =
+         [&](
+            Effect& effect, EffectSettings& settings,
+            std::shared_ptr<EffectInstance>& pInstance) -> bool {
+         const auto pServices = dynamic_cast<EffectUIServices*>(&effect);
+         return pServices && pServices->ShowHostInterface(effect,
+            GetProjectFrame(project), EffectUI::DialogFactory,
+            pInstance,
+            *std::make_shared<SimpleEffectSettingsAccess>(settings),
+            effect.IsBatchProcessing() ) != 0;
+      };
+      if (EffectAndCommandPluginManager::Get().PromptUser(
+             ID, project, std::move(dialogInvoker)))
+         res = EffectAndCommandPluginManager::Get().GetEffectParameters(ID);
+   }
    return res;
 }
 
 wxString MacroCommands::PromptForPresetFor(const CommandID & command, const wxString & params, wxWindow *parent)
 {
-   const PluginID & ID =
-      EffectManager::Get().GetEffectByIdentifier(command);
+   const PluginID& ID = PluginManager::Get().GetByCommandIdentifier(command);
    if (ID.empty())
    {
       return wxEmptyString;   // effect not found.
    }
 
-   wxString preset = EffectManager::Get().GetPreset(ID, params, parent);
+   EffectManager::EffectPresetDialog dialog =
+      [parent](
+         EffectPlugin& effect,
+         const wxString& preset) -> std::optional<wxString> {
+      EffectPresetsDialog dlg(parent, &effect);
+      dlg.Layout();
+      dlg.Fit();
+      dlg.SetSize(dlg.GetMinSize());
+      dlg.CenterOnParent();
+      dlg.SetSelected(preset);
+
+      if (dlg.ShowModal())
+         return std::make_optional(dlg.GetSelected());
+      else
+         return {};
+   };
+   wxString preset =
+      EffectManager::Get().GetPreset(ID, params, std::move(dialog));
 
    // Preset will be empty if the user cancelled the dialog, so return the original
    // parameter value.
@@ -513,10 +553,10 @@ bool MacroCommands::ApplyEffectCommand(
 
    bool res = false;
 
-   auto cleanup = EffectManager::Get().SetBatchProcessing(ID);
+   auto cleanup = EffectAndCommandPluginManager::Get().SetBatchProcessing(ID);
 
    // transfer the parameters to the effect...
-   if (EffectManager::Get().SetEffectParameters(ID, params))
+   if (EffectAndCommandPluginManager::Get().SetEffectParameters(ID, params))
    {
       if( plug->GetPluginType() == PluginTypeAudacityCommand )
          // and apply the effect...
@@ -527,11 +567,10 @@ bool MacroCommands::ApplyEffectCommand(
             EffectManager::kDontRepeatLast);
       else
          // and apply the effect...
-         res = EffectUI::DoEffect(ID,
-            Context,
-            EffectManager::kConfigured |
-            EffectManager::kSkipState |
-            EffectManager::kDontRepeatLast);
+         res = EffectUI::DoEffect(
+            ID, Context.project,
+            EffectManager::kConfigured | EffectManager::kSkipState |
+               EffectManager::kDontRepeatLast);
    }
 
    return res;
@@ -539,11 +578,10 @@ bool MacroCommands::ApplyEffectCommand(
 
 bool MacroCommands::ApplyCommand( const TranslatableString &friendlyCommand,
    const CommandID & command, const wxString & params,
-   CommandContext const * pContext)
+   CommandContext const *const pContext)
 {
    // Test for an effect.
-   const PluginID & ID =
-      EffectManager::Get().GetEffectByIdentifier( command );
+   const PluginID& ID = PluginManager::Get().GetByCommandIdentifier(command);
    if (!ID.empty())
    {
       if( pContext )
@@ -554,11 +592,10 @@ bool MacroCommands::ApplyCommand( const TranslatableString &friendlyCommand,
          ID, friendlyCommand, command, params, context);
    }
 
-   AudacityProject *project = &mProject;
-   auto &manager = CommandManager::Get( *project );
-   if( pContext ){
+   if (pContext) {
+      assert(&pContext->project == &GetProject());
       if( CommandDispatch::HandleTextualCommand(
-         manager, command, *pContext, AlwaysEnabledFlag, true ) )
+         command, *pContext, AlwaysEnabledFlag, true ) )
          return true;
       pContext->Status( wxString::Format(
          _("Your batch command of %s was not recognized."), friendlyCommand.Translation() ));
@@ -568,7 +605,7 @@ bool MacroCommands::ApplyCommand( const TranslatableString &friendlyCommand,
    {
       const CommandContext context(  mProject );
       if( CommandDispatch::HandleTextualCommand(
-         manager, command, context, AlwaysEnabledFlag, true ) )
+         command, context, AlwaysEnabledFlag, true ) )
          return true;
    }
 
@@ -584,10 +621,11 @@ bool MacroCommands::ApplyCommandInBatchMode(
    const CommandID & command, const wxString &params,
    CommandContext const * pContext)
 {
+   assert(!pContext || &pContext->project == &GetProject());
    AudacityProject *project = &mProject;
    auto &settings = ProjectSettings::Get( *project );
    // Recalc flags and enable items that may have become enabled.
-   MenuManager::Get(*project).UpdateMenus(false);
+   CommandManager::Get(*project).UpdateMenus(false);
    // enter batch mode...
    project->mBatchMode++;
    auto cleanup = finally( [&] {
@@ -660,7 +698,6 @@ bool MacroCommands::ApplyMacro(
             undoManager.Undo(
                [&]( const UndoStackElem &elem ){
                   history.PopState( elem.state ); } );
-            undoManager.AbandonRedo();
          });
       }
    });
