@@ -12,4 +12,8 @@
 
 class wxFileName;
 
+//! Update Audacity 1.0 file in-place to XML format
+/*! @return true if successful, else no effect on the file
+ @excsafety{Strong}
+ */
 bool ConvertLegacyProjectFile(const wxFileName &filename);
