@@ -796,7 +796,7 @@ bool ProjectAudioManager::DoRecord(AudacityProject &project,
       wxString name;
       for (auto i = 1; ; ++i) {
          //i18n-hint a numerical suffix added to distinguish otherwise like-named clips when new record started
-         name = XC("%s #%d", "clip name template")
+         name = XC("%s.%d", "clip name template")
             .Format(track.GetName(), i).Translation();
          if (!track.HasClipNamed(name))
             break;
