@@ -52,6 +52,7 @@ is time to refresh some aspect of the screen.
 #include "AdornedRulerPanel.h"
 #include "tracks/ui/CommonTrackPanelCell.h"
 #include "KeyboardCapture.h"
+#include "PendingTracks.h"
 #include "Project.h"
 #include "ProjectAudioIO.h"
 #include "ProjectAudioManager.h"
@@ -79,6 +80,7 @@ is time to refresh some aspect of the screen.
 #include "TrackArtist.h"
 #include "TrackPanelAx.h"
 #include "TrackPanelResizerCell.h"
+#include "Viewport.h"
 #include "WaveTrack.h"
 
 #include "FrameStatistics.h"
@@ -99,7 +101,7 @@ is time to refresh some aspect of the screen.
 #include "RealtimeEffectManager.h"
 
 static_assert( kVerticalPadding == kTopMargin + kBottomMargin );
-static_assert( kTrackInfoBtnSize == kAffordancesAreaHeight, "Drag bar is misaligned with the menu button");
+static_assert( kTrackInfoTitleHeight + kTrackInfoTitleExtra == kAffordancesAreaHeight, "Drag bar is misaligned with the menu button");
 
 /**
 
@@ -261,7 +263,6 @@ TrackPanel::TrackPanel(wxWindow * parent, wxWindowID id,
                        AdornedRulerPanel * ruler)
    : CellularPanel(parent, id, pos, size, viewInfo,
                    wxWANTS_CHARS | wxNO_BORDER),
-     mListener( &ProjectWindow::Get( *project ) ),
      mTracks(tracks),
      mRuler(ruler),
      mTrackArtist(nullptr),
@@ -275,20 +276,25 @@ TrackPanel::TrackPanel(wxWindow * parent, wxWindowID id,
    SetName(XO("Track Panel"));
    SetBackgroundStyle(wxBG_STYLE_PAINT);
 
+#if wxUSE_ACCESSIBILITY
+   // Inject finder of track rectangles into the accessibility helper
    {
-      auto pAx = std::make_unique <TrackPanelAx>( *project );
-      pAx->SetWindow( this );
-      wxWeakRef< TrackPanel > weakThis{ this };
-      pAx->SetFinder(
-         [weakThis]( const Track &track ) -> wxRect {
-            if (weakThis)
-               return weakThis->FindTrackRect( &track );
-            return {};
-         }
-      );
-      TrackFocus::Get( *GetProject() ).SetAccessible(
-         *this, std::move( pAx ) );
+      const auto finder = [
+         weakThis = wxWeakRef<TrackPanel>{ this }
+      ] (const Track &track) -> wxRect {
+         if (weakThis)
+            return weakThis->FindTrackRect(&track);
+         return {};
+      };
+      auto &focus = TrackFocus::Get(*GetProject());
+      auto &viewport = Viewport::Get(*GetProject());
+      TrackPanelAx *pAx{};
+      SetAccessible(pAx =
+         safenew TrackPanelAx{
+            viewport.weak_from_this(), focus.weak_from_this(), finder });
+      focus.SetCallbacks(std::make_unique<TrackPanelAx::Adapter>(pAx));
    }
+#endif
 
    mTrackArtist = std::make_unique<TrackArtist>( this );
 
@@ -299,16 +305,14 @@ TrackPanel::TrackPanel(wxWindow * parent, wxWindowID id,
       &TrackPanel::OnIdle, this);
 
    // Register for tracklist updates
-   mTrackListSubscription =
-   mTracks->Subscribe([this](const TrackListEvent &event){
+   mTrackListSubscription = PendingTracks::Get(*GetProject())
+   .Subscribe([this](const TrackListEvent &event){
       switch (event.mType) {
       case TrackListEvent::RESIZING:
       case TrackListEvent::ADDITION:
          OnTrackListResizing(event); break;
       case TrackListEvent::DELETION:
          OnTrackListDeletion(); break;
-      case TrackListEvent::TRACK_REQUEST_VISIBLE:
-         OnEnsureVisible(event); break;
       default:
          break;
       }
@@ -337,6 +341,8 @@ TrackPanel::TrackPanel(wxWindow * parent, wxWindowID id,
 
    mProjectRulerInvalidatedSubscription =
       ProjectTimeRuler::Get(*theProject).GetRuler().Subscribe([this](auto mode) { Refresh(); });
+   mSelectionSubscription = viewInfo->selectedRegion
+      .Subscribe([this](auto&){ Refresh(false); });
 
    UpdatePrefs();
 }
@@ -412,6 +418,7 @@ void TrackPanel::OnTimer(wxTimerEvent& )
 
    AudacityProject *const p = GetProject();
    auto &window = ProjectWindow::Get( *p );
+   auto &viewport = Viewport::Get(*p);
 
    auto &projectAudioIO = ProjectAudioIO::Get( *p );
    auto gAudioIO = AudioIO::Get();
@@ -431,7 +438,7 @@ void TrackPanel::OnTimer(wxTimerEvent& )
          !gAudioIO->IsAudioTokenActive(projectAudioIO.GetAudioIOToken()))
    {
       projectAudioIO.SetAudioIOToken(0);
-      window.RedrawProject();
+      viewport.Redraw();
    }
    if (mLastDrawnSelectedRegion != mViewInfo->selectedRegion) {
       UpdateSelectionDisplay();
@@ -524,14 +531,17 @@ void TrackPanel::OnPaint(wxPaintEvent & /* event */)
 
 void TrackPanel::MakeParentRedrawScrollbars()
 {
-   mListener->TP_RedrawScrollbars();
+   Viewport::Get(*GetProject()).UpdateScrollbarsForTracks();
 }
 
 namespace {
-   std::shared_ptr<Track> FindTrack(TrackPanelCell *pCell )
+   std::shared_ptr<Track> FindTrack(TrackPanelCell *pCell)
    {
       if (pCell)
-         return static_cast<CommonTrackPanelCell*>( pCell )->FindTrack();
+         // FindTrack as applied through the CommonTrackPanelCell interface
+         // will really find a track, though for now it finds a left or right
+         // channel.
+         return static_cast<CommonTrackPanelCell*>(pCell)->FindTrack();
       return {};
    }
 }
@@ -554,7 +564,7 @@ void TrackPanel::ProcessUIHandleResult
 
    // Copy data from the underlying tracks to the pending tracks that are
    // really displayed
-   TrackList::Get( *panel->GetProject() ).UpdatePendingTracks();
+   PendingTracks::Get(*panel->GetProject()).UpdatePendingTracks();
 
    using namespace RefreshCode;
 
@@ -562,8 +572,8 @@ void TrackPanel::ProcessUIHandleResult
       panel->UpdateViewIfNoTracks();
       // Beware stale pointer!
       if (pLatestTrack == pClickedTrack)
-         pLatestTrack = NULL;
-      pClickedTrack = NULL;
+         pLatestTrack = nullptr;
+      pClickedTrack = nullptr;
    }
 
    if (pClickedTrack && (refreshResult & RefreshCode::UpdateVRuler))
@@ -594,22 +604,26 @@ void TrackPanel::ProcessUIHandleResult
       panel->MakeParentRedrawScrollbars();
 
    if (refreshResult & Resize)
-      panel->GetListener()->TP_HandleResize();
+      Viewport::Get(*GetProject()).HandleResize();
 
    if ((refreshResult & RefreshCode::EnsureVisible) && pClickedTrack) {
-      TrackFocus::Get(*GetProject()).Set(pClickedTrack);
-      pClickedTrack->EnsureVisible();
+      auto & focus = TrackFocus::Get(*GetProject());
+      focus.Set(pClickedTrack);
+      if (const auto pFocus = focus.Get())
+         Viewport::Get(*GetProject()).ShowTrack(*pFocus);
    }
 }
 
 void TrackPanel::HandlePageUpKey()
 {
-   mListener->TP_ScrollWindow(2 * mViewInfo->h - mViewInfo->GetScreenEndTime());
+   Viewport::Get(*GetProject())
+      .SetHorizontalThumb(2 * mViewInfo->hpos - mViewInfo->GetScreenEndTime());
 }
 
 void TrackPanel::HandlePageDownKey()
 {
-   mListener->TP_ScrollWindow(mViewInfo->GetScreenEndTime());
+   Viewport::Get(*GetProject())
+      .SetHorizontalThumb(mViewInfo->GetScreenEndTime());
 }
 
 bool TrackPanel::IsAudioActive()
@@ -657,9 +671,9 @@ void TrackPanel::UpdateViewIfNoTracks()
 
       // PRL:  Following causes the time ruler to align 0 with left edge.
       // Bug 972
-      mViewInfo->h = 0;
+      mViewInfo->hpos = 0;
 
-      mListener->TP_HandleResize();
+      Viewport::Get(*GetProject()).HandleResize();
       //STM: Clear message if all tracks are removed
       ProjectStatus::Get( *GetProject() ).Set({});
    }
@@ -676,7 +690,7 @@ void TrackPanel::OnTrackListResizing(const TrackListEvent &e)
       UpdateVRuler(t.get());
 
    // fix for bug 2477
-   mListener->TP_RedrawScrollbars();
+   MakeParentRedrawScrollbars();
 }
 
 // Tracks have been removed from the list.
@@ -729,13 +743,14 @@ void TrackPanel::OnMouseEvent(wxMouseEvent & event)
 
 
    if (event.ButtonUp()) {
-      //EnsureVisible should be called after processing the up-click.
+      //ShowTrack should be called after processing the up-click.
       this->CallAfter( [this, event]{
          const auto foundCell = FindCell(event.m_x, event.m_y);
          const auto t = FindTrack( foundCell.pCell.get() );
-         if ( t ) {
-            TrackFocus::Get(*GetProject()).Set(t.get());
-            t->EnsureVisible();
+         if (t) {
+            auto &focus = TrackFocus::Get(*GetProject());
+            focus.Set(t.get());
+            Viewport::Get(*GetProject()).ShowTrack(*t);
          }
       } );
    }
@@ -755,9 +770,6 @@ void TrackPanel::RefreshTrack(Track *trk, bool refreshbacking)
    if (!trk)
       return;
 
-   // Always move to the first channel of the group, and use only
-   // the sum of channel heights, not the height of any channel alone!
-   trk = *GetTracks()->Find(trk);
    auto height = ChannelView::GetChannelGroupHeight(trk);
 
    // Set rectangle top according to the scrolling position, `vpos`
@@ -812,7 +824,7 @@ void TrackPanel::Refresh(bool eraseBackground /* = TRUE */,
 
 void TrackPanel::OnAudioIO(AudioIOEvent evt)
 {
-   if (evt.type == AudioIOEvent::MONITOR)
+   if (evt.type == AudioIOEvent::MONITOR || evt.type == AudioIOEvent::PAUSE)
       return;
    // Some hit tests want to change their cursor to and from the ban symbol
    CallAfter( [this]{ CellularPanel::HandleCursorForPresentMouseState(); } );
@@ -831,6 +843,8 @@ void TrackPanel::DrawTracks(wxDC * dc)
 
    const SelectedRegion &sr = mViewInfo->selectedRegion;
    mTrackArtist->pSelectedRegion = &sr;
+   const auto &pendingTracks = PendingTracks::Get(*GetProject());
+   mTrackArtist->pPendingTracks = &pendingTracks;
    mTrackArtist->pZoomInfo = mViewInfo;
    TrackPanelDrawingContext context {
       *dc, Target(), mLastMouseState, mTrackArtist.get()
@@ -852,10 +866,10 @@ void TrackPanel::DrawTracks(wxDC * dc)
 #endif
 
    const bool hasSolo = GetTracks()->Any<PlayableTrack>()
-      .any_of( [](const PlayableTrack *pt) {
+      .any_of( [&](const PlayableTrack *pt) {
          pt = static_cast<const PlayableTrack *>(
-            pt->SubstitutePendingChangedTrack().get());
-         return (pt && pt->GetSolo());
+            &pendingTracks.SubstitutePendingChangedTrack(*pt));
+         return pt->GetSolo();
       } );
 
    mTrackArtist->drawEnvelope = envelopeFlag;
@@ -879,12 +893,8 @@ std::shared_ptr< CommonTrackPanelCell > TrackPanel::GetBackgroundCell()
 }
 
 namespace {
-/*!
- @pre `t.IsLeader()`
- */
 std::vector<int> FindAdjustedChannelHeights(Track &t)
 {
-   assert(t.IsLeader());
    auto channels = t.Channels();
    assert(!channels.empty());
 
@@ -939,15 +949,13 @@ void TrackPanel::UpdateVRulers()
 void TrackPanel::UpdateVRuler(Track *t)
 {
    if (t)
-      UpdateTrackVRuler(**TrackList::Channels(t).begin());
+      UpdateTrackVRuler(*t);
 
    UpdateVRulerSize();
 }
 
 void TrackPanel::UpdateTrackVRuler(Track &t)
 {
-   assert(t.IsLeader());
-
    auto heights = FindAdjustedChannelHeights(t);
 
    wxRect rect(mViewInfo->GetVRulerOffset(),
@@ -992,7 +1000,7 @@ void TrackPanel::UpdateVRulerSize()
       // Find maximum width over all channels
       for (auto t : trackRange)
          for (auto pChannel : t->Channels()) {
-            auto &size = ChannelView::Get(*pChannel).vrulerSize;
+            const auto &size = ChannelView::Get(*pChannel).vrulerSize;
             s.IncTo({ size.first, size.second });
          }
 
@@ -1009,80 +1017,9 @@ void TrackPanel::UpdateVRulerSize()
 void TrackPanel::OnTrackMenu(Track *t)
 {
    CellularPanel::DoContextMenu(
-      t ? &ChannelView::Get(*t->GetChannel(0)) : nullptr);
+      t ? ChannelView::Get(*t->GetChannel(0)).shared_from_this() : nullptr);
 }
 
-// Tracks have been removed from the list.
-void TrackPanel::OnEnsureVisible(const TrackListEvent & e)
-{
-   bool modifyState = e.mExtra;
-   auto pTrack = e.mpTrack.lock();
-   auto t = pTrack.get();
-   // Promised by TrackListEvent for this event type:
-   assert(!t || t->IsLeader());
-   int trackTop = 0;
-   int trackHeight =0;
-   for (auto it : *GetTracks()) {
-      trackTop += trackHeight;
-      trackHeight = ChannelView::GetChannelGroupHeight(it);
-
-      if (it == t) {
-         //We have found the track we want to ensure is visible.
-
-         //Get the size of the trackpanel.
-         int width, height;
-         GetSize(&width, &height);
-
-         if (trackTop < mViewInfo->vpos) {
-            height = mViewInfo->vpos - trackTop + mViewInfo->scrollStep;
-            height /= mViewInfo->scrollStep;
-            mListener->TP_ScrollUpDown(-height);
-         }
-         else if (trackTop + trackHeight > mViewInfo->vpos + height) {
-            height = (trackTop + trackHeight) - (mViewInfo->vpos + height);
-            height = (height + mViewInfo->scrollStep + 1) / mViewInfo->scrollStep;
-            mListener->TP_ScrollUpDown(height);
-         }
-
-         break;
-      }
-   }
-   Refresh(false);
-
-   if (modifyState)
-      ProjectHistory::Get(*GetProject()).ModifyState(false);
-}
-
-// 0.0 scrolls to top
-// 1.0 scrolls to bottom.
-void TrackPanel::VerticalScroll( float fracPosition){
-
-   int trackTop = 0;
-   int trackHeight = 0;
-
-   auto tracks = GetTracks();
-
-   auto range = tracks->Any();
-   if (!range.empty()) {
-      trackHeight = ChannelView::GetChannelGroupHeight(*range.rbegin());
-      --range.second;
-   }
-   trackTop = range.sum(ChannelView::GetChannelGroupHeight);
-
-   int delta;
-
-   //Get the size of the trackpanel.
-   int width, height;
-   GetSize(&width, &height);
-
-   delta = (fracPosition * (trackTop + trackHeight - height)) - mViewInfo->vpos + mViewInfo->scrollStep;
-   //wxLogDebug( "Scroll down by %i pixels", delta );
-   delta /= mViewInfo->scrollStep;
-   mListener->TP_ScrollUpDown(delta);
-   Refresh(false);
-}
-
-
 namespace {
    // Drawing constants
    // DisplaceX and MarginX are large enough to avoid overwriting <- symbol
@@ -1130,85 +1067,6 @@ wxRect GetTrackNameRect(
    };
 }
 
-// Draws the track name on the track, if it is needed.
-void DrawTrackName(int leftOffset, TrackPanelDrawingContext &context,
-   const Channel &channel, const wxRect & rect)
-{
-   if (!TrackArtist::Get(context)->mbShowTrackNameInTrack)
-      return;
-   auto &track = *GetTrack(channel).SubstitutePendingChangedTrack();
-   auto name = track.GetName();
-   if (name.IsEmpty())
-      return;
-   if (!track.IsLeader())
-      return;
-   auto &dc = context.dc;
-   wxBrush Brush;
-   wxCoord textWidth, textHeight;
-   GetTrackNameExtent(dc, channel, &textWidth, &textHeight);
-
-   // Logic for name background translucency (aka 'shields')
-   // Tracks less than kOpaqueHeight high will have opaque shields.
-   // Tracks more than kTranslucentHeight will have maximum translucency for shields.
-   const int kOpaqueHeight = 44;
-   const int kTranslucentHeight = 124;
-
-   // PRL:  to do:  reexamine this strange use of ChannelView::GetHeight,
-   // ultimately to compute an opacity
-   int h = ChannelView::Get(channel).GetHeight();
-
-   // f codes the opacity as a number between 0.0 and 1.0
-   float f = wxClip((h-kOpaqueHeight)/(float)(kTranslucentHeight-kOpaqueHeight),0.0,1.0);
-   // kOpaque is the shield's alpha for tracks that are not tall
-   // kTranslucent is the shield's alpha for tracks that are tall.
-   const int kOpaque = 255;
-   const int kTranslucent = 140;
-   // 0.0 maps to full opacity, 1.0 maps to full translucency.
-   int opacity = 255 - (255-140)*f;
-
-   const auto nameRect =
-      GetTrackNameRect( leftOffset, rect, textWidth, textHeight );
-
-#ifdef __WXMAC__
-   // Mac dc is a graphics dc already.
-   AColor::UseThemeColour( &dc, clrTrackInfoSelected, clrTrackPanelText, opacity );
-   dc.DrawRoundedRectangle( nameRect, 8.0 );
-#else
-   // This little dance with wxImage in order to draw to a graphic dc
-   // which we can then paste as a translucent bitmap onto the real dc.
-   enum : int {
-      SecondMarginX = 1, SecondMarginY = 1,
-      SecondMarginsX = 2 * SecondMarginX, SecondMarginsY = 2 * SecondMarginY,
-   };
-   wxImage image(
-      textWidth + MarginsX + SecondMarginsX,
-      textHeight + MarginsY + SecondMarginsY );
-   image.InitAlpha();
-   unsigned char *alpha=image.GetAlpha();
-   memset(alpha, wxIMAGE_ALPHA_TRANSPARENT, image.GetWidth()*image.GetHeight());
-
-   {
-      std::unique_ptr< wxGraphicsContext >
-         pGc{ wxGraphicsContext::Create(image) };
-      auto &gc = *pGc;
-      // This is to a gc, not a dc.
-      AColor::UseThemeColour( &gc, clrTrackInfoSelected, clrTrackPanelText, opacity );
-      // Draw at 1,1, not at 0,0 to avoid clipping of the antialiasing.
-      gc.DrawRoundedRectangle(
-         SecondMarginX, SecondMarginY,
-         textWidth + MarginsX, textHeight + MarginsY, 8.0 );
-      // destructor of gc updates the wxImage.
-   }
-   wxBitmap bitmap( image );
-   dc.DrawBitmap( bitmap,
-      nameRect.x - SecondMarginX, nameRect.y - SecondMarginY );
-#endif
-   dc.SetTextForeground(theTheme.Colour( clrTrackPanelText ));
-   dc.DrawText(track.GetName(),
-      nameRect.x + MarginX,
-      nameRect.y + MarginY);
-}
-
 /*
 
   The following classes define the subdivision of the area of the TrackPanel
@@ -1317,10 +1175,8 @@ struct VRulersAndChannels final : TrackPanelGroup {
    {
       // This overpaints the track area, but sometimes too the stereo channel
       // separator, so draw at least later than that
+
       if ( iPass == TrackArtist::PassBorders ) {
-         DrawTrackName(mLeftOffset, context, *mpChannel, rect);
-      }
-      if ( iPass == TrackArtist::PassControls ) {
          if (mRefinement.size() > 1) {
             // Draw lines separating sub-views
             auto &dc = context.dc;
@@ -1328,76 +1184,18 @@ struct VRulersAndChannels final : TrackPanelGroup {
             auto iter = mRefinement.begin() + 1, end = mRefinement.end();
             for ( ; iter != end; ++iter ) {
                auto yy = iter->first;
+               AColor::Line(dc, rect.x, yy, mLeftOffset - 1, yy);
                AColor::Line( dc, mLeftOffset, yy, rect.GetRight(), yy );
             }
          }
       }
    }
 
-   wxRect DrawingArea(
-      TrackPanelDrawingContext &context,
-      const wxRect &rect, const wxRect &panelRect, unsigned iPass ) override
-   {
-      auto result = rect;
-      if ( iPass == TrackArtist::PassBorders ) {
-         if ( true ) {
-            wxCoord textWidth, textHeight;
-            GetTrackNameExtent(context.dc, *mpChannel, &textWidth, &textHeight);
-            result =
-               GetTrackNameRect( mLeftOffset, rect, textWidth, textHeight );
-         }
-      }
-      return result;
-   }
-
    std::shared_ptr<Channel> mpChannel;
    ChannelView::Refinement mRefinement;
    wxCoord mLeftOffset;
 };
 
-//Simply fills area using specified brush and outlines borders
-class EmptyPanelRect final : public CommonTrackPanelCell
-{
-   //Required to keep selection behaviour similar to others
-   std::shared_ptr<Channel> mpChannel;
-   int mFillBrushName;
-public:
-   /*!
-    @pre `pChannel != nullptr`
-    */
-   explicit EmptyPanelRect(
-      const std::shared_ptr<Channel>& pChannel, int fillBrushName
-   )  : mpChannel{ pChannel }, mFillBrushName{ fillBrushName }
-   {
-   }
-
-   ~EmptyPanelRect() { }
-
-   void Draw(TrackPanelDrawingContext& context,
-      const wxRect& rect, unsigned iPass) override
-   {
-      if (iPass == TrackArtist::PassBackground)
-      {
-         context.dc.SetPen(*wxTRANSPARENT_PEN);
-         AColor::UseThemeColour(&context.dc, mFillBrushName);
-         context.dc.DrawRectangle(rect);
-         wxRect bevel(rect.x, rect.y, rect.width - 1, rect.height - 1);
-         AColor::BevelTrackInfo(context.dc, true, bevel, false);
-      }
-   }
-
-   std::shared_ptr<Track> DoFindTrack() override
-   {
-      return GetTrack(*mpChannel).shared_from_this();
-   }
-
-   std::vector<UIHandlePtr> HitTest(const TrackPanelMouseState& state,
-      const AudacityProject* pProject) override
-   {
-      return {};
-   }
-};
-
 //Simply place children one after another horizontally, without any specific logic
 struct HorizontalGroup final : TrackPanelGroup {
 
@@ -1420,9 +1218,6 @@ struct HorizontalGroup final : TrackPanelGroup {
 // alternating with n - 1 resizers;
 // each channel-ruler pair might be divided into multiple views
 struct ChannelStack final : TrackPanelGroup {
-   /*!
-    @pre `pTrack->IsLeader()`
-    */
    ChannelStack(const std::shared_ptr<Track> &pTrack, wxCoord leftOffset)
       : mpTrack{ pTrack }, mLeftOffset{ leftOffset } {}
    Subdivision Children(const wxRect &rect_) override
@@ -1438,11 +1233,7 @@ struct ChannelStack final : TrackPanelGroup {
       for (auto pChannel : channels) {
          auto &view = ChannelView::Get(*pChannel);
          if (auto affordance = view.GetAffordanceControls()) {
-            auto panelRect = std::make_shared<EmptyPanelRect>(pChannel,
-               mpTrack->GetSelected()
-                  ? clrTrackInfoSelected : clrTrackInfo);
             Refinement hgroup {
-               std::make_pair(rect.GetLeft() + 1, panelRect),
                std::make_pair(mLeftOffset, affordance)
             };
             refinement
@@ -1473,11 +1264,36 @@ struct ChannelStack final : TrackPanelGroup {
       const wxRect& rect, unsigned iPass) override
    {
       TrackPanelGroup::Draw(context, rect, iPass);
+      if (iPass == TrackArtist::PassTracks)
+      {
+         auto vRulerRect = rect;
+         vRulerRect.width = mLeftOffset - rect.x;
+
+         auto dc = &context.dc;
+
+         // Paint the background;
+         AColor::MediumTrackInfo(dc, mpTrack->GetSelected() );
+         dc->DrawRectangle( vRulerRect );
+
+         const auto channels = mpTrack->Channels();
+         auto& view = ChannelView::Get(**channels.begin());
+         if(auto affordance = view.GetAffordanceControls())
+         {
+            const auto yy = vRulerRect.y + kAffordancesAreaHeight - 1;
+            AColor::Dark( dc, false );
+            AColor::Line( *dc, vRulerRect.GetLeft(), yy, vRulerRect.GetRight(), yy );
+         }
+
+         // Stroke left and right borders
+         dc->SetPen(*wxBLACK_PEN);
+         
+         AColor::Line( *dc, vRulerRect.GetLeftTop(), vRulerRect.GetLeftBottom() );
+         AColor::Line( *dc, vRulerRect.GetRightTop(), vRulerRect.GetRightBottom() );
+      }
       if (iPass == TrackArtist::PassFocus && mpTrack->IsSelected()) {
          const auto channels = mpTrack->Channels();
          const auto pLast = *channels.rbegin();
          wxCoord yy = rect.GetTop();
-         assert(mpTrack->IsLeader()); // by construction
          auto heights = FindAdjustedChannelHeights(*mpTrack);
          auto pHeight = heights.begin();
          for (auto pChannel : channels) {
@@ -1503,9 +1319,6 @@ struct ChannelStack final : TrackPanelGroup {
 // A track control panel, left of n vertical rulers and n channels
 // alternating with n - 1 resizers
 struct LabeledChannelGroup final : TrackPanelGroup {
-   /*!
-    @pre `pTrack->IsLeader()`
-    */
    LabeledChannelGroup(
       const std::shared_ptr<Track> &pTrack, wxCoord leftOffset)
          : mpTrack{ pTrack }, mLeftOffset{ leftOffset } {}
@@ -1533,15 +1346,18 @@ struct LabeledChannelGroup final : TrackPanelGroup {
          );
 
          // shadow
-         // Stroke lines along bottom and right, which are slightly short at
-         // bottom-left and top-right
-         const auto right = rect.GetRight();
-         const auto bottom = rect.GetBottom();
+         if constexpr (kShadowThickness > 0)
+         {
+            // Stroke lines along bottom and right, which are slightly short at
+            // bottom-left and top-right
+            const auto right = rect.GetRight();
+            const auto bottom = rect.GetBottom();
 
-         // bottom
-         AColor::Line(dc, rect.x + 2, bottom, right, bottom);
-         // right
-         AColor::Line(dc, right, rect.y + 2, right, bottom);
+            // bottom
+            AColor::Line(dc, rect.x + 2, bottom, right, bottom);
+            // right
+            AColor::Line(dc, right, rect.y + 2, right, bottom);
+         }
       }
       if (iPass == TrackArtist::PassFocus) {
          // Sometimes highlight is not drawn on backing bitmap. I thought
@@ -1604,9 +1420,6 @@ struct LabeledChannelGroup final : TrackPanelGroup {
 // Stacks a label and a single or multi-channel track on a resizer below,
 // which is associated with the last channel
 struct ResizingChannelGroup final : TrackPanelGroup {
-   /*!
-    @pre `pTrack->IsLeader()`
-    */
    ResizingChannelGroup(
       const std::shared_ptr<Track> &pTrack, wxCoord leftOffset)
          : mpTrack{ pTrack }, mLeftOffset{ leftOffset } {}
@@ -1637,15 +1450,15 @@ struct Subgroup final : TrackPanelGroup {
          refinement.emplace_back( yy, EmptyCell::Instance() ),
          yy += kTopMargin;
 
-      for (const auto leader : tracks) {
+      for (const auto pTrack : tracks) {
          wxCoord height = 0;
-         for (auto pChannel : leader->Channels()) {
+         for (auto pChannel : pTrack->Channels()) {
             auto &view = ChannelView::Get(*pChannel);
             height += view.GetHeight();
          }
          refinement.emplace_back( yy,
             std::make_shared<ResizingChannelGroup>(
-               leader->SharedPointer(), viewInfo.GetLeftOffset())
+               pTrack->SharedPointer(), viewInfo.GetLeftOffset())
          );
          yy += height;
       }
@@ -1685,14 +1498,9 @@ std::shared_ptr<TrackPanelNode> TrackPanel::Root()
 // The given track is assumed to be the first channel
 wxRect TrackPanel::FindTrackRect( const Track * target )
 {
-   auto leader = *GetTracks()->Find( target );
-   if (!leader) {
-      return {};
-   }
-
    return CellularPanel::FindRect( [&] ( TrackPanelNode &node ) {
       if (auto pGroup = dynamic_cast<const LabeledChannelGroup*>( &node ))
-         return pGroup->mpTrack.get() == leader;
+         return pGroup->mpTrack.get() == target;
       return false;
    } );
 }
@@ -1737,13 +1545,12 @@ std::vector<wxRect> TrackPanel::FindRulerRects(const Channel &target)
    return results;
 }
 
-TrackPanelCell *TrackPanel::GetFocusedCell()
+std::shared_ptr<TrackPanelCell> TrackPanel::GetFocusedCell()
 {
-   // Note that focus track is always a leader
    auto pTrack = TrackFocus::Get(*GetProject()).Get();
    return pTrack
-      ? &ChannelView::Get(*pTrack->GetChannel(0))
-      : GetBackgroundCell().get();
+      ? ChannelView::Get(*pTrack->GetChannel(0)).shared_from_this()
+      : GetBackgroundCell();
 }
 
 void TrackPanel::SetFocusedCell()
@@ -1754,8 +1561,10 @@ void TrackPanel::SetFocusedCell()
    KeyboardCapture::Capture(this);
 }
 
-void TrackPanel::OnTrackFocusChange(TrackFocusChangeMessage)
+void TrackPanel::OnTrackFocusChange(TrackFocusChangeMessage message)
 {
+   if (message.focusPanel)
+      SetFocus();
    if (auto cell = GetFocusedCell())
-      Refresh( false );
+      Refresh(false);
 }
