@@ -19,20 +19,20 @@ namespace TrackUtilities {
    enum MoveChoice {
       OnMoveUpID, OnMoveDownID, OnMoveTopID, OnMoveBottomID
    };
-   /// Move a track up, down, to top or to bottom.
+   //! Move a track up, down, to top or to bottom.
    AUDACITY_DLL_API void DoMoveTrack(
-      AudacityProject &project, Track* target, MoveChoice choice );
-   // "exclusive" mute means mute the chosen track and unmute all others.
+      AudacityProject &project, Track &target, MoveChoice choice);
+   //! "exclusive" mute means mute the chosen track and unmute all others.
    AUDACITY_DLL_API
-   void DoTrackMute( AudacityProject &project, Track *pTrack, bool exclusive );
-   // Type of solo (standard or simple) follows the set preference, unless
-   // exclusive == true, which causes the opposite behavior.
+   void DoTrackMute(AudacityProject &project, Track &track, bool exclusive);
+   //! Type of solo (standard or simple) follows the set preference, unless
+   //! exclusive == true, which causes the opposite behavior.
    AUDACITY_DLL_API
-   void DoTrackSolo( AudacityProject &project, Track *pTrack, bool exclusive );
+   void DoTrackSolo(AudacityProject &project, Track &track, bool exclusive);
    AUDACITY_DLL_API
-   void DoRemoveTrack( AudacityProject &project, Track * toRemove );
+   void DoRemoveTrack(AudacityProject &project, Track &toRemove);
    AUDACITY_DLL_API
-   void DoRemoveTracks( AudacityProject & );
+   void DoRemoveTracks(AudacityProject &);
 
 }
 
