@@ -15,6 +15,8 @@
 struct AudioIOStartStreamOptions;
 class CommandContext;
 class SelectedRegion;
+class TrackList;
+class TransportSequences;
 enum class PlayMode : int;
 
 struct AUDACITY_DLL_API TransportUtilities
@@ -37,4 +39,10 @@ struct AUDACITY_DLL_API TransportUtilities
 
 };
 
+/*!
+ @param nonWaveToo if true, collect all PlayableTracks
+ */
+TransportSequences MakeTransportTracks(
+   TrackList &trackList, bool selectedOnly, bool nonWaveToo = false);
+
 #endif
