@@ -17,15 +17,16 @@
 
 #include "HelpCommand.h"
 
-#include "CommandDispatch.h"
-#include "CommandManager.h"
 #include "../CommonCommandFlags.h"
-#include "SettingsVisitor.h"
-#include "LoadCommands.h"
-#include "ShuttleGui.h"
-#include "CommandTargets.h"
 #include "CommandContext.h"
-#include "../effects/EffectManager.h"
+#include "CommandDispatch.h"
+#include "CommandTargets.h"
+#include "EffectAndCommandPluginManager.h"
+#include "LoadCommands.h"
+#include "MenuRegistry.h"
+#include "PluginManager.h"
+#include "SettingsVisitor.h"
+#include "ShuttleGui.h"
 
 const ComponentInterfaceSymbol HelpCommand::Symbol
 { XO("Help") };
@@ -46,7 +47,7 @@ enum {
 static const EnumValueSymbol kFormats[nFormats] =
 {
    // These are acceptable dual purpose internal/visible names
-   
+
    /* i18n-hint JavaScript Object Notation */
    { XO("JSON") },
    /* i18n-hint name of a computer programming language */
@@ -86,7 +87,7 @@ bool HelpCommand::Apply(const CommandContext &context)
 
    if( mFormat == kLisp )
    {
-      CommandContext LispyContext( 
+      CommandContext LispyContext(
          context.project,
          std::make_unique<LispifiedCommandOutputTargets>( *context.pOutput.get() )
          );
@@ -95,7 +96,7 @@ bool HelpCommand::Apply(const CommandContext &context)
 
    if( mFormat == kBrief )
    {
-      CommandContext BriefContext( 
+      CommandContext BriefContext(
          context.project,
          std::make_unique<BriefCommandOutputTargets>( *context.pOutput.get() )
          );
@@ -106,12 +107,11 @@ bool HelpCommand::Apply(const CommandContext &context)
 }
 
 bool HelpCommand::ApplyInner(const CommandContext & context){
-   EffectManager & em = EffectManager::Get();
-   PluginID ID = em.GetEffectByIdentifier( mCommandName );
+   PluginID ID = PluginManager::Get().GetByCommandIdentifier(mCommandName);
    if( ID.empty() )
       context.Status( "Command not found" );
    else
-      em.GetCommandDefinition( ID, context, 1);
+      EffectAndCommandPluginManager::Get().GetCommandDefinition(ID, context, 1);
    return true;
 }
 
@@ -139,18 +139,18 @@ void CommentCommand::PopulateOrExchange(ShuttleGui & S)
 }
 
 namespace {
-using namespace MenuTable;
+using namespace MenuRegistry;
 
 // Register menu items
 
 AttachedItem sAttachment{
-   wxT("Optional/Extra/Part2/Scriptables2"),
    // Note that the PLUGIN_SYMBOL must have a space between words,
    // whereas the short-form used here must not.
    // (So if you did write "Compare Audio" for the PLUGIN_SYMBOL name, then
    // you would have to use "CompareAudio" here.)
    Command( wxT("Help"), XXO("Help..."),
-      CommandDispatch::OnAudacityCommand, AudioIONotBusyFlag() )
+      CommandDispatch::OnAudacityCommand, AudioIONotBusyFlag() ),
+   wxT("Optional/Extra/Part2/Scriptables2")
 };
 
 }
