@@ -10,13 +10,12 @@
 #define __AUDACITY_CONTRAST_DIALOG__
 
 #include "wxPanelWrapper.h" // to inherit
+#include "ContrastBase.h"
 
 class wxButton;
 class wxTextCtrl;
 
-class Envelope;
 class NumericTextCtrl;
-class WaveTrack;
 
 //----------------------------------------------------------------------------
 // ContrastDialog
@@ -24,7 +23,7 @@ class WaveTrack;
 
 // Declare window functions
 
-class ContrastDialog final : public wxDialogWrapper
+class ContrastDialog final : public ContrastBase, public wxDialogWrapper
 {
 public:
    // constructors and destructors
@@ -43,14 +42,6 @@ public:
    NumericTextCtrl *mBackgroundStartT;
    NumericTextCtrl *mBackgroundEndT;
 
-   double mT0;
-   double mT1;
-   double mProjectRate;
-   double mStartTimeF;
-   double mEndTimeF;
-   double mStartTimeB;
-   double mEndTimeB;
-
 private:
    // handlers
    void OnChar(wxKeyEvent &event);
@@ -67,18 +58,7 @@ private:
    wxTextCtrl *mPassFailText;
    wxTextCtrl *mDiffText;
 
-   float foregrounddB;
-   float backgrounddB;
-   bool  mForegroundIsDefined;
-   bool  mBackgroundIsDefined;
-   double mT0orig;
-   double mT1orig;
-
-   bool mDoBackground;
-   bool GetDB(float & dB);
-   void SetStartAndEndTime();
-
-   double length;
+   AudacityProject& GetProject() override;
 
    DECLARE_EVENT_TABLE()
 
