@@ -19,17 +19,22 @@
 #include "AllThemeResources.h"
 #include "widgets/BasicMenu.h"
 #include "BasicUI.h"
+#include "CommandManager.h"
 #include "ConfigInterface.h"
 #include "EffectManager.h"
+#include "DoEffect.h"
 #include "PluginManager.h"
 #include "ProjectAudioIO.h"
 #include "ProjectHistory.h"
 #include "../ProjectWindowBase.h"
-#include "../TrackPanelAx.h"
+#include "../ProjectWindows.h"
+#include "TrackFocus.h"
 #include "RealtimeEffectList.h"
 #include "RealtimeEffectManager.h"
 #include "RealtimeEffectState.h"
 #include "Theme.h"
+#include "UndoManager.h"
+#include "Viewport.h"
 #include "wxWidgetsWindowPlacement.h"
 
 static PluginID GetID(EffectPlugin &effect)
@@ -96,14 +101,12 @@ private:
 #include "../../images/Effect.h"
 #include "AudioIO.h"
 #include "../CommonCommandFlags.h"
-#include "../Menus.h"
 #include "../prefs/GUISettings.h" // for RTL_WORKAROUND
 #include "Project.h"
 #include "../ProjectAudioManager.h"
 #include "ShuttleGui.h"
 #include "ViewInfo.h"
-#include "../commands/AudacityCommand.h"
-#include "../commands/CommandContext.h"
+#include "CommandContext.h"
 #include "AudacityMessageBox.h"
 #include "HelpSystem.h"
 #include "../widgets/AButton.h"
@@ -250,7 +253,7 @@ EffectUIHost::EffectUIHost(wxWindow *parent,
 #if defined(__WXMAC__)
    MacMakeWindowFloating(GetHandle());
 #endif
-   
+
    SetName( effect.GetDefinition().GetName() );
 
    // This style causes Validate() and TransferDataFromWindow() to visit
@@ -295,7 +298,7 @@ bool EffectUIHost::TransferDataFromWindow()
    //! Do other custom validation and transfer actions
    if (!mpEditor->ValidateUI())
       return false;
-   
+
    // Transfer-from takes non-const reference to settings
    bool result = true;
    mpAccess->ModifySettings([&](EffectSettings &settings){
@@ -348,18 +351,14 @@ AButton* MakeBitmapToggleButton(wxWindow *parent,
    pBtn->SetImages(ImageOff, ImageOff, ImageOn, ImageOn, ImageOff);
    return pBtn;
 }
+   constexpr int InnerMargin = 3;
 }
 
-void EffectUIHost::BuildButtonBar(ShuttleGui &S, bool graphicalUI)
+void EffectUIHost::BuildTopBar(ShuttleGui &S)
 {
-   mIsGUI = graphicalUI;
-   mIsBatch = mEffectUIHost.IsBatchProcessing();
-
-   constexpr int margin = 3;
-
    S.StartPanel();
    {
-      S.SetBorder( margin );
+      S.SetBorder( InnerMargin );
 
       S.StartHorizontalLay(wxEXPAND, 0);
       {
@@ -367,6 +366,7 @@ void EffectUIHost::BuildButtonBar(ShuttleGui &S, bool graphicalUI)
          {
             mEnableBtn = MakeBitmapToggleButton(S.GetParent(),
                theTheme.Image(bmpEffectOn), theTheme.Image(bmpEffectOff));
+            mEnableBtn->SetBackgroundColour(GetBackgroundColour());
             S
                .Position(wxALIGN_CENTER | wxTOP | wxBOTTOM)
                .Name(XO("Power"))
@@ -379,36 +379,7 @@ void EffectUIHost::BuildButtonBar(ShuttleGui &S, bool graphicalUI)
 
          S.AddSpace(1, 0, 1);
 
-         if (!mIsBatch)
-         {
-            if (!IsOpenedFromEffectPanel() &&
-               (mEffectUIHost.GetDefinition().GetType() != EffectTypeAnalyze) &&
-               (mEffectUIHost.GetDefinition().GetType() != EffectTypeTool) )
-            {
-               mPlayToggleBtn = S.Id(kPlayID)
-                  .ToolTip(XO("Preview effect"))
-                  .AddButton( { },
-                              wxALIGN_CENTER | wxTOP | wxBOTTOM );
-            }
-            if(mPlayToggleBtn != nullptr)
-            {
-               //wxButton does not implement GetSizeFromText
-               //set button minimum size so that largest text fits
-               mPlayToggleBtn->SetLabel(_("Stop &Preview"));
-               auto a = mPlayToggleBtn->GetBestSize();
-               mPlayToggleBtn->SetLabel(_("&Preview"));
-               auto b = mPlayToggleBtn->GetBestSize();
-               mPlayToggleBtn->SetMinSize(a.x > b.x ? a : b);
-            }
-         }
 
-         if (!IsOpenedFromEffectPanel())
-         {
-            mApplyBtn = S.Id(wxID_APPLY)
-               .AddButton( XXO("&Apply"),
-                           wxALIGN_CENTER | wxTOP | wxBOTTOM );
-            mApplyBtn->SetDefault();
-         }
 
          if (mEffectUIHost.GetDefinition().EnablesDebug())
          {
@@ -431,6 +402,8 @@ bool EffectUIHost::Initialize()
    EffectPanel *w {};
    ShuttleGui S{ this, eIsCreating };
    {
+      BuildTopBar(S);
+
       // Make the panel for the client
       Destroy_ptr<EffectPanel> uw{ safenew EffectPanel( S.GetParent() ) };
       RTL_WORKAROUND(uw.get());
@@ -446,7 +419,8 @@ bool EffectUIHost::Initialize()
       if (!mpEditor)
          return false;
 
-      BuildButtonBar(S, mpEditor->IsGraphicalUI());
+      mIsGUI = mpEditor->IsGraphicalUI();
+      mIsBatch = mEffectUIHost.IsBatchProcessing();
 
       S.StartHorizontalLay( wxEXPAND );
       {
@@ -455,6 +429,38 @@ bool EffectUIHost::Initialize()
             .AddWindow((w = uw.release()));
       }
       S.EndHorizontalLay();
+
+      if (!IsOpenedFromEffectPanel())
+      {
+         S.StartPanel();
+         {
+            S.SetBorder( InnerMargin );
+            S.StartHorizontalLay(wxEXPAND, 0);
+            {
+               if (!mIsBatch)
+               {
+                  if (mEffectUIHost.GetDefinition().GetType() != EffectTypeAnalyze &&
+                     mEffectUIHost.GetDefinition().GetType() != EffectTypeTool)
+                  {
+                     S.Id(kPlayID)
+                        .ToolTip(XO("Preview effect"))
+                        .AddButton( XXO("&Preview"),
+                                    wxALIGN_CENTER | wxTOP | wxBOTTOM );
+                  }
+               }
+
+               S.AddSpace(1, 1, 1);
+               S.Id(wxID_CANCEL)
+                  .AddButton(XXO("&Cancel"));
+
+               mApplyBtn = S.Id(wxID_APPLY)
+                  .AddButton( XXO("&Apply"));
+               mApplyBtn->SetDefault();
+            }
+            S.EndHorizontalLay();
+         }
+         S.EndPanel();
+      }
    }
 
    Layout();
@@ -490,11 +496,11 @@ void EffectUIHost::OnInitDialog(wxInitDialogEvent & evt)
 {
    // Do default handling
    wxDialogWrapper::OnInitDialog(evt);
-   
+
 #if wxCHECK_VERSION(3, 0, 0)
    //#warning "check to see if this still needed in wx3"
 #endif
-   
+
    // Pure hackage coming down the pike...
    //
    // I have no idea why, but if a wxTextCtrl is the first control in the
@@ -517,7 +523,7 @@ void EffectUIHost::OnErase(wxEraseEvent & WXUNUSED(evt))
 void EffectUIHost::OnPaint(wxPaintEvent & WXUNUSED(evt))
 {
    wxPaintDC dc(this);
-   
+
    dc.Clear();
 }
 
@@ -528,10 +534,10 @@ void EffectUIHost::OnClose(wxCloseEvent & WXUNUSED(evt))
 
    if (mpEditor)
       mpEditor->OnClose();
-   
+
    Hide();
    Destroy();
-   
+
 #if wxDEBUG_LEVEL
    mClosed = true;
 #endif
@@ -559,14 +565,14 @@ void EffectUIHost::OnApply(wxCommandEvent & evt)
    {
       auto flags = AlwaysEnabledFlag;
       bool allowed =
-      MenuManager::Get( project ).ReportIfActionNotAllowed(
+      CommandManager::Get( project ).ReportIfActionNotAllowed(
          mEffectUIHost.GetDefinition().GetName(),
          flags,
          WaveTracksSelectedFlag() | TimeSelectedFlag());
       if (!allowed)
          return;
    }
-   
+
    if (!TransferDataFromWindow() ||
        // This is the main place where there is a side-effect on the config
        // file to remember the last-used settings of an effect, just before
@@ -578,14 +584,14 @@ void EffectUIHost::OnApply(wxCommandEvent & evt)
    if (IsModal())
    {
       mDismissed = true;
-      
+
       EndModal(evt.GetId());
-      
+
       Close();
-      
+
       return;
    }
-   
+
    // Progress dialog no longer yields, so this "shouldn't" be necessary (yet to be proven
    // for sure), but it is a nice visual cue that something is going on.
    mApplyBtn->Disable();
@@ -595,7 +601,7 @@ void EffectUIHost::OnApply(wxCommandEvent & evt)
    // This is absolute hackage...but easy and I can't think of another way just now.
    //
    // It should callback to the EffectManager to kick off the processing
-   EffectUI::DoEffect(GetID(mEffectUIHost), context,
+   EffectUI::DoEffect(GetID(mEffectUIHost), context.project,
       EffectManager::kConfigured);
 }
 
@@ -615,7 +621,7 @@ void EffectUIHost::DoCancel()
          EndModal(0);
       else
          Hide();
-      
+
       mDismissed = true;
    }
 }
@@ -648,7 +654,7 @@ void EffectUIHost::OnMenu(wxCommandEvent & WXUNUSED(evt))
    menu.Bind(wxEVT_MENU, [](auto&){}, kUserPresetsDummyID);
    menu.Bind(wxEVT_MENU, [](auto&){}, kDeletePresetDummyID);
    LoadUserPresets();
-   
+
    if (mUserPresets.size() == 0)
    {
       menu.Append(kUserPresetsDummyID, _("User Presets"))->Enable(false);
@@ -662,9 +668,9 @@ void EffectUIHost::OnMenu(wxCommandEvent & WXUNUSED(evt))
       }
       menu.Append(0, _("User Presets"), sub.release());
    }
-   
+
    menu.Append(kSaveAsID, _("Save Preset..."));
-   
+
    if (mUserPresets.size() == 0)
    {
       menu.Append(kDeletePresetDummyID, _("Delete Preset"))->Enable(false);
@@ -678,11 +684,11 @@ void EffectUIHost::OnMenu(wxCommandEvent & WXUNUSED(evt))
       }
       menu.Append(0, _("Delete Preset"), sub.release());
    }
-   
+
    menu.AppendSeparator();
-   
+
    auto factory = mEffectUIHost.GetDefinition().GetFactoryPresets();
-   
+
    {
       auto sub = std::make_unique<wxMenu>();
       sub->Append(kDefaultsID, _("Defaults"));
@@ -696,13 +702,13 @@ void EffectUIHost::OnMenu(wxCommandEvent & WXUNUSED(evt))
             {
                label = _("None");
             }
-            
+
             sub->Append(kFactoryPresetsID + i, label);
          }
       }
       menu.Append(0, _("Factory Presets"), sub.release());
    }
-   
+
    menu.AppendSeparator();
    menu.Append(kImportID, _("Import..."))
       ->Enable(mEffectUIHost.CanExportPresets());
@@ -712,10 +718,10 @@ void EffectUIHost::OnMenu(wxCommandEvent & WXUNUSED(evt))
    menu.Append(kOptionsID, _("Options..."))
       ->Enable(mEffectUIHost.HasOptions());
    menu.AppendSeparator();
-   
+
    {
       auto sub = std::make_unique<wxMenu>();
-      
+
       auto &definition = mEffectUIHost.GetDefinition();
       sub->Append(kDummyID, wxString::Format(_("Type: %s"),
          ::wxGetTranslation( definition.GetFamily().Translation() )));
@@ -728,7 +734,7 @@ void EffectUIHost::OnMenu(wxCommandEvent & WXUNUSED(evt))
 
       menu.Append(0, _("About"), sub.release());
    }
-   
+
    wxWindow *btn = FindWindow(kMenuID);
    wxRect r = btn->GetRect();
    BasicMenu::Handle{ &menu }.Popup(
@@ -754,7 +760,7 @@ void EffectUIHost::OnPlay(wxCommandEvent & WXUNUSED(evt))
 {
    if (!TransferDataFromWindow())
       return;
-   
+
    auto updater = [this]{ TransferDataToWindow(); };
    EffectPreview(mEffectUIHost, *mpAccess, updater, false);
    // After restoration of settings and effect state:
@@ -779,7 +785,7 @@ void EffectUIHost::OnCapture(AudioIOEvent evt)
 void EffectUIHost::OnUserPreset(wxCommandEvent & evt)
 {
    int preset = evt.GetId() - kUserPresetsID;
-   
+
    mpAccess->ModifySettings([&](EffectSettings &settings){
       // ignore failure
       return mEffectUIHost.GetDefinition().LoadUserPreset(
@@ -803,7 +809,7 @@ void EffectUIHost::OnFactoryPreset(wxCommandEvent & evt)
 void EffectUIHost::OnDeletePreset(wxCommandEvent & evt)
 {
    auto preset = mUserPresets[evt.GetId() - kDeletePresetID];
-   
+
    int res = AudacityMessageBox(
                                 XO("Are you sure you want to delete \"%s\"?").Format( preset ),
                                 XO("Delete Preset"),
@@ -813,9 +819,9 @@ void EffectUIHost::OnDeletePreset(wxCommandEvent & evt)
       RemoveConfigSubgroup(mEffectUIHost.GetDefinition(),
          PluginSettings::Private, UserPresetsGroup(preset));
    }
-   
+
    LoadUserPresets();
-   
+
    return;
 }
 
@@ -824,9 +830,9 @@ void EffectUIHost::OnSaveAs(wxCommandEvent & WXUNUSED(evt))
    wxTextCtrl *text;
    wxString name;
    wxDialogWrapper dlg(this, wxID_ANY, XO("Save Preset"));
-   
+
    ShuttleGui S(&dlg, eIsCreating);
-   
+
    S.StartPanel();
    {
       S.StartVerticalLay(1);
@@ -842,20 +848,20 @@ void EffectUIHost::OnSaveAs(wxCommandEvent & WXUNUSED(evt))
       S.EndVerticalLay();
    }
    S.EndPanel();
-   
+
    dlg.SetSize(dlg.GetSizer()->GetMinSize());
    dlg.Center();
    dlg.Fit();
-   
+
    while (true)
    {
       int rc = dlg.ShowModal();
-      
+
       if (rc != wxID_OK)
       {
          break;
       }
-      
+
       name = text->GetValue();
       if (name.empty())
       {
@@ -867,7 +873,7 @@ void EffectUIHost::OnSaveAs(wxCommandEvent & WXUNUSED(evt))
          md.ShowModal();
          continue;
       }
-      
+
       if ( make_iterator_range( mUserPresets ).contains( name ) )
       {
          AudacityMessageDialog md(
@@ -881,21 +887,21 @@ void EffectUIHost::OnSaveAs(wxCommandEvent & WXUNUSED(evt))
          {
             break;
          }
-         
+
          if (choice == wxID_NO)
          {
             continue;
          }
       }
-      
+
       if (TransferDataFromWindow())
          mEffectUIHost.GetDefinition()
             .SaveUserPreset(UserPresetsGroup(name), mpAccess->Get());
       LoadUserPresets();
-      
+
       break;
    }
-   
+
    return;
 }
 
@@ -917,14 +923,14 @@ void EffectUIHost::OnExport(wxCommandEvent & WXUNUSED(evt))
    // exceptions are handled in AudacityApp::OnExceptionInMainLoop
    if (TransferDataFromWindow())
      mClient.ExportPresets(mEffectUIHost, mpAccess->Get());
-   
+
    return;
 }
 
 void EffectUIHost::OnOptions(wxCommandEvent & WXUNUSED(evt))
 {
    mClient.ShowOptions(mEffectUIHost);
-   
+
    return;
 }
 
@@ -953,7 +959,7 @@ void EffectUIHost::OnCharHook(wxKeyEvent& evt)
       evt.Skip();
       return;
    }
-   
+
    if (IsOpenedFromEffectPanel())
       Close();
    else
@@ -973,19 +979,19 @@ wxBitmap EffectUIHost::CreateBitmap(const char * const xpm[], bool up, bool push
 {
    wxMemoryDC dc;
    wxBitmap pic(xpm);
-   
+
    wxBitmap mod(pic.GetWidth() + 6, pic.GetHeight() + 6, 24);
    dc.SelectObject(mod);
-   
+
 #if defined(__WXGTK__)
    wxColour newColour = wxSystemSettings::GetColour(wxSYS_COLOUR_BACKGROUND);
 #else
    wxColour newColour = wxSystemSettings::GetColour(wxSYS_COLOUR_BTNFACE);
 #endif
-   
+
    dc.SetBackground(wxBrush(newColour));
    dc.Clear();
-   
+
    int offset = 3;
    if (pusher)
    {
@@ -994,11 +1000,11 @@ wxBitmap EffectUIHost::CreateBitmap(const char * const xpm[], bool up, bool push
          offset += 1;
       }
    }
-   
+
    dc.DrawBitmap(pic, offset, offset, true);
-   
+
    dc.SelectObject(wxNullBitmap);
-   
+
    return mod;
 }
 
@@ -1021,12 +1027,12 @@ void EffectUIHost::UpdateControls()
 void EffectUIHost::LoadUserPresets()
 {
    mUserPresets.clear();
-   
+
    GetConfigSubgroups(mEffectUIHost.GetDefinition(),
       PluginSettings::Private, UserPresetsGroup(wxEmptyString), mUserPresets);
-   
+
    std::sort( mUserPresets.begin(), mUserPresets.end() );
-   
+
    return;
 }
 
@@ -1036,7 +1042,7 @@ std::shared_ptr<EffectInstance> EffectUIHost::InitializeInstance()
    std::shared_ptr<EffectInstance> result;
 
    auto mpState = mwState.lock();
- 
+
    bool priorState = (mpState != nullptr);
    if (!priorState) {
       auto gAudioIO = AudioIO::Get();
@@ -1074,7 +1080,7 @@ std::shared_ptr<EffectInstance> EffectUIHost::InitializeInstance()
             }
          });
       }
-      
+
       mInitialized = true;
    }
    else
@@ -1131,215 +1137,9 @@ DialogFactoryResults EffectUI::DialogFactory(wxWindow &parent,
 
 #include "PluginManager.h"
 #include "ProjectRate.h"
-#include "../ProjectWindow.h"
 #include "../SelectUtilities.h"
-#include "../TrackPanel.h"
 #include "WaveTrack.h"
-#include "../commands/CommandManager.h"
-
-/// DoEffect() takes a PluginID and executes the associated effect.
-///
-/// At the moment flags are used only to indicate whether to prompt for
-//  parameters, whether to save the state to history and whether to allow
-/// 'Repeat Last Effect'.
-
-/* static */ bool EffectUI::DoEffect(
-   const PluginID & ID, const CommandContext &context, unsigned flags )
-{
-   AudacityProject &project = context.project;
-   auto &tracks = TrackList::Get( project );
-   auto &trackPanel = TrackPanel::Get( project );
-   auto &trackFactory = WaveTrackFactory::Get( project );
-   auto rate = ProjectRate::Get(project).GetRate();
-   auto &selectedRegion = ViewInfo::Get( project ).selectedRegion;
-   auto &commandManager = CommandManager::Get( project );
-   auto &window = ProjectWindow::Get( project );
-
-   const PluginDescriptor *plug = PluginManager::Get().GetPlugin(ID);
-
-   if (!plug || !PluginManager::IsPluginAvailable(*plug))
-   {
-      BasicUI::ShowMessageBox(
-         XO("This plugin could not be loaded.\nIt may have been deleted."),
-         BasicUI::MessageBoxOptions()
-            .Caption(XO("Plugin Error")));
-
-      return false;
-   }
-
-   EffectType type = plug->GetEffectType();
-
-   // Make sure there's no activity since the effect is about to be applied
-   // to the project's tracks.  Mainly for Apply during RTP, but also used
-   // for batch commands
-   if (flags & EffectManager::kConfigured)
-   {
-      ProjectAudioManager::Get( project ).Stop();
-      //Don't Select All if repeating Generator Effect
-      if (!(flags & EffectManager::kConfigured)) {
-         SelectUtilities::SelectAllIfNone(project);
-      }
-   }
-
-   auto nTracksOriginally = tracks.Size();
-   wxWindow *focus = wxWindow::FindFocus();
-   wxWindow *parent = nullptr;
-   if (focus != nullptr) {
-      parent = focus->GetParent();
-   }
-
-   bool success = false;
-   auto cleanup = finally( [&] {
-
-      if (!success) {
-         // For now, we're limiting realtime preview to a single effect, so
-         // make sure the menus reflect that fact that one may have just been
-         // opened.
-         MenuManager::Get(project).UpdateMenus( false );
-      }
-
-   } );
-
-   const auto range = tracks.Selected<const WaveTrack>();
-   bool anyTracks = !range.empty();
-   bool clean = std::all_of(range.begin(), range.end(),
-      [](const WaveTrack *t){ return t->GetEndTime() == 0; });
-
-   EffectManager & em = EffectManager::Get();
-
-   em.SetSkipStateFlag( false );
-   success = false;
-   if (auto effect = dynamic_cast<Effect*>(em.GetEffect(ID))) {
-      if (const auto pSettings = em.GetDefaultSettings(ID)) {
-         const auto pAccess =
-            std::make_shared<SimpleEffectSettingsAccess>(*pSettings);
-         const auto finder =
-         [effect, &window, pAccess, flags] (EffectSettings &settings)
-            -> std::optional<std::shared_ptr<EffectInstanceEx>>
-         {
-            // Prompting will be bypassed when applying an effect that has
-            // already been configured, e.g. repeating the last effect on a
-            // different selection.  Prompting may call EffectPreview
-            std::shared_ptr<EffectInstance> pInstance;
-            std::shared_ptr<EffectInstanceEx> pInstanceEx;
-            if ((flags & EffectManager::kConfigured) == 0 && pAccess) {
-               const auto pServices = dynamic_cast<EffectUIServices *>(effect);
-               if (!pServices ||
-                   !pServices->ShowHostInterface(*effect,
-                  window, DialogFactory, pInstance, *pAccess, true)
-               )
-                  return {};
-               else if (!(pInstanceEx =
-                  std::dynamic_pointer_cast<EffectInstanceEx>(pInstance)
-               ))
-                  return {};
-               else
-                  // Retrieve again after the dialog modified settings
-                  settings = pAccess->Get();
-            }
-            return { pInstanceEx };
-         };
-         pAccess->ModifySettings([&](EffectSettings &settings){
-            success = effect->DoEffect(settings, finder,
-               rate,
-               &tracks,
-               &trackFactory,
-               selectedRegion,
-               flags,
-               pAccess);
-            return nullptr;
-         });
-      }
-   }
-
-   if (!success)
-      return false;
-
-   if (em.GetSkipStateFlag())
-      flags = flags | EffectManager::kSkipState;
-
-   if (!(flags & EffectManager::kSkipState))
-   {
-      auto shortDesc = em.GetCommandName(ID);
-      auto longDesc = em.GetCommandDescription(ID);
-      ProjectHistory::Get( project ).PushState(longDesc, shortDesc);
-   }
-
-   if (!(flags & EffectManager::kDontRepeatLast))
-   {
-      // Remember a successful generator, effect, analyzer, or tool Process
-         auto shortDesc = em.GetCommandName(ID);
-         /* i18n-hint: %s will be the name of the effect which will be
-          * repeated if this menu item is chosen */
-         auto lastEffectDesc = XO("Repeat %s").Format(shortDesc);
-         auto& menuManager = MenuManager::Get(project);
-         switch ( type ) {
-         case EffectTypeGenerate:
-            commandManager.Modify(wxT("RepeatLastGenerator"), lastEffectDesc);
-            menuManager.mLastGenerator = ID;
-            menuManager.mRepeatGeneratorFlags = EffectManager::kConfigured;
-            break;
-         case EffectTypeProcess:
-            commandManager.Modify(wxT("RepeatLastEffect"), lastEffectDesc);
-            menuManager.mLastEffect = ID;
-            menuManager.mRepeatEffectFlags = EffectManager::kConfigured;
-            break;
-         case EffectTypeAnalyze:
-            commandManager.Modify(wxT("RepeatLastAnalyzer"), lastEffectDesc);
-            menuManager.mLastAnalyzer = ID;
-            menuManager.mLastAnalyzerRegistration = MenuCreator::repeattypeplugin;
-            menuManager.mRepeatAnalyzerFlags = EffectManager::kConfigured;
-            break;
-         case EffectTypeTool:
-            commandManager.Modify(wxT("RepeatLastTool"), lastEffectDesc);
-            menuManager.mLastTool = ID;
-            menuManager.mLastToolRegistration = MenuCreator::repeattypeplugin;
-            menuManager.mRepeatToolFlags = EffectManager::kConfigured;
-            if (shortDesc == NYQUIST_PROMPT_NAME) {
-               menuManager.mRepeatToolFlags = EffectManager::kRepeatNyquistPrompt;  //Nyquist Prompt is not configured
-            }
-            break;
-      }
-   }
-
-   //STM:
-   //The following automatically re-zooms after sound was generated.
-   // IMO, it was disorienting, removing to try out without re-fitting
-   //mchinen:12/14/08 reapplying for generate effects
-   if (type == EffectTypeGenerate)
-   {
-      if (!anyTracks || (clean && selectedRegion.t0() == 0.0))
-         window.DoZoomFit();
-         //  trackPanel->Refresh(false);
-   }
-
-   // PRL:  RedrawProject explicitly because sometimes history push is skipped
-   window.RedrawProject();
-
-   if (focus != nullptr && focus->GetParent()==parent) {
-      focus->SetFocus();
-   }
-
-   // A fix for Bug 63
-   // New tracks added?  Scroll them into view so that user sees them.
-   // Don't care what track type.  An analyser might just have added a
-   // Label track and we want to see it.
-   if (tracks.Size() > nTracksOriginally) {
-      // 0.0 is min scroll position, 1.0 is max scroll position.
-      trackPanel.VerticalScroll( 1.0 );
-   }
-   else {
-      auto pTrack = *tracks.Selected().begin();
-      if (!pTrack)
-         pTrack = *tracks.begin();
-      if (pTrack) {
-         TrackFocus::Get(project).Set(pTrack);
-         pTrack->EnsureVisible();
-      }
-   }
-
-   return true;
-}
+#include "CommandManager.h"
 
 ///////////////////////////////////////////////////////////////////////////////
 BEGIN_EVENT_TABLE(EffectDialog, wxDialogWrapper)
