@@ -6,6 +6,7 @@
 #include <wx/choice.h>
 #include <wx/textctrl.h>
 #include <wx/radiobut.h>
+#include <wx/regex.h>
 #include <wx/wupdlock.h>
 
 #include "Export.h"
@@ -268,7 +269,7 @@ void ExportFilePanel::Init(const wxFileName& filename,
                false);
          for(const auto track : waveTracks)
          {
-            if(TrackList::NChannels(*track) >= 2 || track->GetPan() != .0f)
+            if(track->NChannels() >= 2 || track->GetPan() != .0f)
             {
                numChannels = 2;
                break;
@@ -341,10 +342,11 @@ int ExportFilePanel::GetSampleRate() const
    return mSampleRate;
 }
 
-ExportProcessor::Parameters ExportFilePanel::GetParameters() const
+std::optional<ExportProcessor::Parameters> ExportFilePanel::GetParameters() const
 {
-   mOptionsHandler->TransferDataFromEditor();
-   return mOptionsHandler->GetParameters();
+   if(mOptionsHandler->TransferDataFromEditor())
+      return { mOptionsHandler->GetParameters() };
+   return std::nullopt;
 }
 
 int ExportFilePanel::GetChannels() const
@@ -370,23 +372,36 @@ void ExportFilePanel::ValidateAndFixExt()
 
    wxFileName filename;
    filename.SetFullName(mFullName->GetValue());
+   const auto desiredExt = filename.GetExt().Trim();
 
-   //Remove extra whitespaces
-   auto desiredExt = filename.GetExt().Trim().Trim(false);
-
-   auto it = std::find_if(
-      formatInfo.extensions.begin(),
-      formatInfo.extensions.end(),
-      // if typed extension uses different case (e.g. MP3 instead of mp3)
-      // we'll reset the file extension to one provided by FormatInfo
-      [&](const auto& ext) { return desiredExt.IsSameAs(ext, false); });
-
-   if(it == formatInfo.extensions.end())
-      it = formatInfo.extensions.begin();
-
-   if(!it->empty() && !it->IsSameAs(filename.GetExt()))
+   //See https://github.com/audacity/audacity/issues/5823
+   //check if extension is valid, i.e. does not contain whitespace characters.
+   //Otherwise everything after '.'(if present) is considered to be a part of name.
+   if(wxRegEx{R"(^[^ ]+$)"}.Matches(desiredExt))
    {
-      filename.SetExt(*it);
+      auto it = std::find_if(
+         formatInfo.extensions.begin(),
+         formatInfo.extensions.end(),
+         // if typed extension uses different case (e.g. MP3 instead of mp3)
+         // we'll reset the file extension to one provided by FormatInfo
+         [&](const auto& ext) { return desiredExt.IsSameAs(ext, false); });
+
+      if(it == formatInfo.extensions.end())
+         it = formatInfo.extensions.begin();
+
+      if(!it->empty() && !it->IsSameAs(filename.GetExt()))
+      {
+         filename.SetExt(*it);
+         mFullName->SetValue(filename.GetFullName());
+      }
+   }
+   else if(!formatInfo.extensions.front().empty())
+   {
+      auto fullname = filename.GetFullName();
+      if(!fullname.EndsWith("."))
+         fullname.Append(".");
+      fullname.Append(formatInfo.extensions.front());
+      filename.SetFullName(fullname);
       mFullName->SetValue(filename.GetFullName());
    }
 }
@@ -498,9 +513,8 @@ void ExportFilePanel::ChangeFormat(int index)
 
       mSelectedPlugin = plugin;
       mSelectedFormatIndex = formatIndex;
-      
-      auto formatInfo = plugin->GetFormatInfo(formatIndex);
-      UpdateFileNameExt(formatInfo.extensions[0]);
+
+      ValidateAndFixExt();
 
       mAudioOptionsPanel->SetSizer(nullptr);
       mAudioOptionsPanel->DestroyChildren();
@@ -509,6 +523,7 @@ void ExportFilePanel::ChangeFormat(int index)
       mOptionsHandler = std::make_unique<ExportOptionsHandler>(S, *plugin, formatIndex);
       mOptionsChangeSubscription = mOptionsHandler->Subscribe(*this, &ExportFilePanel::OnOptionsHandlerEvent);
 
+      const auto formatInfo = plugin->GetFormatInfo(formatIndex);
       UpdateMaxChannels(formatInfo.maxChannels);
       
       UpdateSampleRateList();
@@ -530,25 +545,14 @@ void ExportFilePanel::OnOptionsHandlerEvent(const ExportOptionsHandlerEvent &e)
       break;
    case ExportOptionsHandlerEvent::FormatInfoChange:
       {
-         auto formatInfo = mSelectedPlugin->GetFormatInfo(mSelectedFormatIndex);
-         UpdateFileNameExt(formatInfo.extensions[0]);
+         const auto formatInfo = mSelectedPlugin->GetFormatInfo(mSelectedFormatIndex);
+         ValidateAndFixExt();
          UpdateMaxChannels(formatInfo.maxChannels);
       } break;
    }
    
 }
 
-void ExportFilePanel::UpdateFileNameExt(const wxString& ext)
-{
-   if(!ext.empty())
-   {
-      wxFileName filename;
-      filename.SetFullName(mFullName->GetValue());
-      filename.SetExt(ext.BeforeFirst(' ').Lower());
-      mFullName->SetValue(filename.GetFullName());
-   }
-}
-
 void ExportFilePanel::UpdateMaxChannels(unsigned maxChannels)
 {
    if(maxChannels < 2 && mStereo->GetValue())
