@@ -14,18 +14,14 @@
 #include <memory>
 
 class AudacityProject;
+class Track;
 class WaveTrackFactory;
-class WaveTrack;
 class wxString;
 class wxWindow;
 
 #include <vector>
 
-// Newly constructed WaveTracks that are not yet owned by a TrackList
-// are held in unique_ptr not shared_ptr
-using NewChannelGroup = std::vector< std::shared_ptr<WaveTrack> >;
-using TrackHolders = std::vector< NewChannelGroup >;
-
+using TrackHolders = std::vector<std::shared_ptr<Track>>;
 
 void ImportRaw(const AudacityProject &project, wxWindow *parent, const wxString &fileName,
    WaveTrackFactory *trackFactory, TrackHolders &outTracks);
