@@ -26,20 +26,17 @@ other settings.
 
 #include "MidiIOPrefs.h"
 
-#ifdef EXPERIMENTAL_MIDI_OUT
-
 #include <wx/defs.h>
 
 #include <wx/choice.h>
-#include <wx/intl.h>
 #include <wx/textctrl.h>
 
 #include <portmidi.h>
 
 #include "NoteTrack.h"
 #include "Prefs.h"
-#include "../ShuttleGui.h"
-#include "../widgets/AudacityMessageBox.h"
+#include "ShuttleGui.h"
+#include "AudacityMessageBox.h"
 
 enum {
    HostID = 10000,
@@ -297,7 +294,6 @@ bool MidiIOPrefs::Validate()
    return true;
 }
 
-#ifdef EXPERIMENTAL_MIDI_OUT
 namespace{
 PrefsPanel::Registration sAttachment{ "MidiIO",
    [](wxWindow *parent, wxWindowID winid, AudacityProject *)
@@ -311,6 +307,3 @@ PrefsPanel::Registration sAttachment{ "MidiIO",
    { "", { Registry::OrderingHint::After, "Recording" } }
 };
 }
-#endif
-
-#endif
