@@ -32,6 +32,7 @@ class AudacityProject;
 class AUDACITY_DLL_API ControlToolBar final : public ToolBar {
 
  public:
+   static Identifier ID();
 
    ControlToolBar( AudacityProject &project );
    virtual ~ControlToolBar();
@@ -84,12 +85,6 @@ class AUDACITY_DLL_API ControlToolBar final : public ToolBar {
  private:
    void UpdateStatusBar();
 
-   static
-   void MakeAlternateImages(AButton &button, int idx,
-                            teBmps eEnabledUp,
-                            teBmps eEnabledDown,
-                            teBmps eDisabled);
-
    void ArrangeButtons();
    TranslatableString StateForStatusBar();
 
