@@ -22,10 +22,10 @@
 
 #include "ClientData.h"
 #include "GlobalVariable.h"
+#include "Observer.h"
 #include "ToolDock.h"
 
-#include "../commands/CommandFunctors.h"
-#include "../commands/CommandManager.h"
+#include "CommandFunctors.h"
 
 
 class wxCommandEvent;
@@ -64,23 +64,23 @@ class AUDACITY_DLL_API ToolManager final
    static const ToolManager &Get( const AudacityProject &project );
 
    ToolManager( AudacityProject *parent );
-   ToolManager( const ToolManager & ) PROHIBITED;
-   ToolManager &operator=( const ToolManager & ) PROHIBITED;
+   ToolManager( const ToolManager & ) = delete;
+   ToolManager &operator=( const ToolManager & ) = delete;
    ~ToolManager();
 
    void CreateWindows();
 
    void LayoutToolBars();
 
-   bool IsDocked( int type );
+   bool IsDocked( Identifier type ) const;
 
-   bool IsVisible( int type );
+   bool IsVisible( Identifier type ) const;
 
-   void ShowHide( int type );
+   void ShowHide( Identifier type );
 
-   void Expose( int type, bool show );
+   void Expose( Identifier type, bool show );
 
-   ToolBar *GetToolBar( int type ) const;
+   ToolBar *GetToolBar(const Identifier &type) const;
 
    ToolDock *GetTopDock();
    const ToolDock *GetTopDock() const;
@@ -97,10 +97,29 @@ class AUDACITY_DLL_API ToolManager final
 
    bool RestoreFocus();
 
+   //! Visit bars, lexicographically by their textual ids
+   template< typename F >
+   void ForEach(F &&fun)
+   {
+      std::for_each(std::begin(mBars), std::end(mBars), [&fun](auto &pair){
+         fun(pair.second.get());
+      });
+   }
+
+   size_t CountBars() const
+   {
+      return mBars.size();
+   }
+
+   static void ModifyToolbarMenus(AudacityProject &project);
+   // Calls ModifyToolbarMenus() on all projects
+   static void ModifyAllProjectToolbarMenus();
+
  private:
 
    ToolBar *Float( ToolBar *t, wxPoint & pos );
 
+   void OnMenuUpdate(struct MenuUpdateMessage);
    void OnTimer( wxTimerEvent & event );
    void OnMouse( wxMouseEvent & event );
    void OnCaptureLost( wxMouseCaptureLostEvent & event );
@@ -116,6 +135,7 @@ class AUDACITY_DLL_API ToolManager final
    void WriteConfig();
    void Updated();
 
+   Observer::Subscription mMenuManagerSubscription;
    AudacityProject *mParent;
    wxWindowRef mLastFocus{};
 
@@ -143,7 +163,8 @@ class AUDACITY_DLL_API ToolManager final
    ToolDock *mTopDock{};
    ToolDock *mBotDock{};
 
-   ToolBar::Holder mBars[ ToolBarCount ];
+   //! map not unordered_map, for the promise made by ForEach
+   std::map<Identifier, ToolBar::Holder> mBars;
 
    wxPoint mPrevPosition {};
    ToolDock *mPrevDock {};
@@ -219,22 +240,22 @@ public:
    DECLARE_EVENT_TABLE()
 };
 
-
+#include "MenuRegistry.h"
 
 // Construct a static instance of this class to add a menu item that shows and
 // hides a toolbar
 struct AUDACITY_DLL_API AttachedToolBarMenuItem : CommandHandlerObject {
    AttachedToolBarMenuItem(
-      ToolBarID id, const CommandID &name, const TranslatableString &label_in,
+      Identifier id, const CommandID &name, const TranslatableString &label_in,
       const Registry::OrderingHint &hint = {},
       // IDs of other toolbars not to be shown simultaneously with this one:
-      std::vector< ToolBarID > excludeIds = {} );
+      std::vector< Identifier > excludeIds = {} );
 
    void OnShowToolBar(const CommandContext &context);
 
-   const ToolBarID mId;
-   const MenuTable::AttachedItem mAttachedItem;
-   const std::vector< ToolBarID > mExcludeIds;
+   const Identifier mId;
+   const MenuRegistry::AttachedItem mAttachedItem;
+   const std::vector< Identifier > mExcludeIds;
 };
 
 #endif
