@@ -11,28 +11,22 @@ Paul Licameli split from TrackPanel.cpp
 
 #ifdef USE_MIDI
 #include "NoteTrackControls.h"
-
-#include "NoteTrackButtonHandle.h"
-#include "Observer.h"
-#include "Theme.h"
-
+#include "NoteTrackDisplayData.h"
+#include "AColor.h"
+#include "AllThemeResources.h"
 #include "../../ui/PlayableTrackButtonHandles.h"
+#include "NoteTrackButtonHandle.h"
 #include "NoteTrackSliderHandles.h"
-
-#include "../../../../HitTestResult.h"
 #include "../../../../TrackArtist.h"
 #include "../../../../TrackPanel.h"
+#include "../../../ui/CommonTrackInfo.h"
 #include "../../../../TrackPanelMouseEvent.h"
-#include "../../../../NoteTrack.h"
+#include "NoteTrack.h"
 #include "../../../../widgets/PopupMenuTable.h"
-#include "Project.h"
 #include "ProjectHistory.h"
 #include "../../../../ProjectWindows.h"
 #include "../../../../RefreshCode.h"
-#include "../../../../prefs/ThemePrefs.h"
-
-#include <mutex>
-#include <wx/app.h>
+#include "Theme.h"
 #include <wx/frame.h>
 
 ///////////////////////////////////////////////////////////////////////////////
@@ -59,14 +53,12 @@ std::vector<UIHandlePtr> NoteTrackControls::HitTest
          if (NULL != (result = SoloButtonHandle::HitTest(
             mSoloHandle, state, rect, pProject, track)))
             return result;
-#ifdef EXPERIMENTAL_MIDI_OUT
          if (NULL != (result = VelocitySliderHandle::HitTest(
             mVelocityHandle, state, rect, track)))
             return result;
          if (NULL != (result = NoteTrackButtonHandle::HitTest(
             mClickHandle, state, rect, track)))
             return result;
-#endif
          return result;
       }();
       if (result) {
@@ -75,7 +67,7 @@ std::vector<UIHandlePtr> NoteTrackControls::HitTest
       }
    }
 
-   return NoteTrackControlsBase::HitTest(st, pProject);
+   return PlayableTrackControls::HitTest(st, pProject);
 }
 
 class NoteTrackMenuTable : public PopupMenuTable
@@ -91,10 +83,10 @@ public:
 private:
    void InitUserData(void *pUserData) override
    {
-      mpData = static_cast<NoteTrackControlsBase::InitMenuData*>(pUserData);
+      mpData = static_cast<PlayableTrackControls::InitMenuData*>(pUserData);
    }
 
-   NoteTrackControlsBase::InitMenuData *mpData{};
+   PlayableTrackControls::InitMenuData *mpData{};
 
    void OnChangeOctave(wxCommandEvent &);
 };
@@ -113,13 +105,13 @@ enum {
 /// Scrolls the note track up or down by an octave
 void NoteTrackMenuTable::OnChangeOctave(wxCommandEvent &event)
 {
-   NoteTrack *const pTrack = static_cast<NoteTrack*>(mpData->pTrack);
+   auto &track = static_cast<NoteTrack&>(mpData->track);
 
    wxASSERT(event.GetId() == OnUpOctaveID
       || event.GetId() == OnDownOctaveID);
 
    const bool bDown = (OnDownOctaveID == event.GetId());
-   pTrack->ShiftNoteRange((bDown) ? -12 : 12);
+   NoteTrackRange::Get(track).ShiftNoteRange((bDown) ? -12 : 12);
 
    AudacityProject *const project = &mpData->project;
    ProjectHistory::Get( *project )
@@ -145,7 +137,6 @@ PopupMenuTable *NoteTrackControls::GetMenuExtension(Track *)
 
 // drawing related
 #include "../../../../widgets/ASlider.h"
-#include "../../../../TrackInfo.h"
 #include "../../../../TrackPanelDrawingContext.h"
 #include "ViewInfo.h"
 
@@ -154,7 +145,7 @@ using TCPLine = TrackInfo::TCPLine;
 #ifdef USE_MIDI
 enum : int {
    // PRL:  was it correct to include the margin?
-   kMidiCellWidth = ( ( kTrackInfoWidth + kLeftMargin ) / 4) - 2,
+   kMidiCellWidth = ( ( kTrackInfoWidth  - CommonTrackInfo::Margin * 2) / 4),
    kMidiCellHeight = kTrackInfoBtnSize
 };
 #endif
@@ -165,11 +156,8 @@ enum : int {
 namespace {
 void GetMidiControlsHorizontalBounds( const wxRect &rect, wxRect &dest )
 {
-   dest.x = rect.x + 1; // To center slightly
-   // PRL: TODO: kMidiCellWidth is defined in terms of the other constant
-   // kTrackInfoWidth but I am trying to avoid use of that constant.
-   // Can cell width be computed from dest.width instead?
-   dest.width = kMidiCellWidth * 4;
+   dest.x = rect.x;
+   dest.width = rect.width / 4 * 4;
 }
 
 void SliderDrawFunction
@@ -180,12 +168,11 @@ void SliderDrawFunction
   bool captured, bool highlight )
 {
    wxRect sliderRect = rect;
-   TrackInfo::GetSliderHorizontalBounds( rect.GetTopLeft(), sliderRect );
+   CommonTrackInfo::GetSliderHorizontalBounds( rect, sliderRect );
    auto nt = static_cast<const NoteTrack*>( pTrack );
    Selector( sliderRect, nt, captured, pParent )->OnPaint(*dc, highlight);
 }
 
-#ifdef EXPERIMENTAL_MIDI_OUT
 void VelocitySliderDrawFunction
 ( TrackPanelDrawingContext &context,
   const wxRect &rect, const Track *pTrack )
@@ -193,7 +180,7 @@ void VelocitySliderDrawFunction
    auto dc = &context.dc;
    auto target = dynamic_cast<VelocitySliderHandle*>( context.target.get() );
    bool hit = target && target->GetTrack().get() == pTrack;
-   bool captured = hit && target->IsClicked();
+   bool captured = hit && target->IsDragging();
 
    const auto artist = TrackArtist::Get( context );
    auto pParent = FindProjectFrame( artist->parent->GetProject() );
@@ -202,7 +189,103 @@ void VelocitySliderDrawFunction
       &NoteTrackControls::VelocitySlider, dc, rect, pTrack,
       pParent, captured, hit);
 }
+
+// Draws the midi channel toggle buttons within the given rect.
+// The rect should be evenly divisible by 4 on both axes.
+static void DrawLabelControls
+( const NoteTrack *pTrack, wxDC & dc, const wxRect &rect, int highlightedChannel )
+{
+   dc.SetTextForeground(theTheme.Colour(clrLabelTrackText));
+   wxASSERT_MSG(rect.width % 4 == 0, "Midi channel control rect width must be divisible by 4");
+   wxASSERT_MSG(rect.height % 4 == 0, "Midi channel control rect height must be divisible by 4");
+
+   auto cellWidth = rect.width / 4;
+   auto cellHeight = rect.height / 4;
+
+   wxRect box;
+   for (int row = 0; row < 4; row++) {
+      for (int col = 0; col < 4; col++) {
+         // chanName is the "external" channel number (1-16)
+         // used by AColor and button labels
+         int chanName = row * 4 + col + 1;
+
+         box.x = rect.x + col * cellWidth;
+         box.y = rect.y + row * cellHeight;
+         box.width = cellWidth;
+         box.height = cellHeight;
+
+         bool visible = pTrack ? pTrack->IsVisibleChan(chanName - 1) : true;
+         if (visible) {
+            // highlightedChannel counts 0 based
+            if ( chanName == highlightedChannel + 1 )
+               AColor::LightMIDIChannel(&dc, chanName);
+            else
+               AColor::MIDIChannel(&dc, chanName);
+            dc.DrawRectangle(box);
+// two choices: channel is enabled (to see and play) when button is in
+// "up" position (original Audacity style) or in "down" position
+//
+#define CHANNEL_ON_IS_DOWN 1
+#if CHANNEL_ON_IS_DOWN
+            AColor::DarkMIDIChannel(&dc, chanName);
+#else
+            AColor::LightMIDIChannel(&dc, chanName);
 #endif
+            AColor::Line(dc, box.x, box.y, box.x + box.width - 1, box.y);
+            AColor::Line(dc, box.x, box.y, box.x, box.y + box.height - 1);
+
+#if CHANNEL_ON_IS_DOWN
+            AColor::LightMIDIChannel(&dc, chanName);
+#else
+            AColor::DarkMIDIChannel(&dc, chanName);
+#endif
+            AColor::Line(dc,
+                         box.x + box.width - 1, box.y,
+                         box.x + box.width - 1, box.y + box.height - 1);
+            AColor::Line(dc,
+                         box.x, box.y + box.height - 1,
+                         box.x + box.width - 1, box.y + box.height - 1);
+         } else {
+            if ( chanName == highlightedChannel + 1 )
+               AColor::LightMIDIChannel(&dc, chanName);
+            else
+               AColor::MIDIChannel(&dc, 0);
+            dc.DrawRectangle(box);
+#if CHANNEL_ON_IS_DOWN
+            AColor::LightMIDIChannel(&dc, 0);
+#else
+            AColor::DarkMIDIChannel(&dc, 0);
+#endif
+            AColor::Line(dc, box.x, box.y, box.x + box.width - 1, box.y);
+            AColor::Line(dc, box.x, box.y, box.x, box.y + box.height - 1);
+
+#if CHANNEL_ON_IS_DOWN
+            AColor::DarkMIDIChannel(&dc, 0);
+#else
+            AColor::LightMIDIChannel(&dc, 0);
+#endif
+            AColor::Line(dc,
+                         box.x + box.width - 1, box.y,
+                         box.x + box.width - 1, box.y + box.height - 1);
+            AColor::Line(dc,
+                         box.x, box.y + box.height - 1,
+                         box.x + box.width - 1, box.y + box.height - 1);
+
+         }
+
+         wxString text;
+         wxCoord w;
+         wxCoord h;
+
+         text.Printf(wxT("%d"), chanName);
+         dc.GetTextExtent(text, &w, &h);
+
+         dc.DrawText(text, box.x + (box.width - w) / 2, box.y + (box.height - h) / 2);
+      }
+   }
+   dc.SetTextForeground(theTheme.Colour(clrTrackPanelText));
+   AColor::MIDIChannel(&dc, 0); // always return with gray color selected
+}
 
 void MidiControlsDrawFunction
 ( TrackPanelDrawingContext &context,
@@ -214,7 +297,7 @@ void MidiControlsDrawFunction
    auto &dc = context.dc;
    wxRect midiRect = rect;
    GetMidiControlsHorizontalBounds(rect, midiRect);
-   NoteTrack::DrawLabelControls
+   DrawLabelControls
       ( static_cast<const NoteTrack *>(pTrack), dc, midiRect, channel );
 }
 }
@@ -222,29 +305,29 @@ void MidiControlsDrawFunction
 static const struct NoteTrackTCPLines
    : TCPLines { NoteTrackTCPLines() {
    *static_cast<TCPLines*>(this) =
-      NoteTrackControlsBase::StaticNoteTCPLines();
+      PlayableTrackControls::StaticNoteTCPLines();
    insert( end(), {
       { TCPLine::kItemMidiControlsRect, kMidiCellHeight * 4, 0,
         MidiControlsDrawFunction },
-#ifdef EXPERIMENTAL_MIDI_OUT
       { TCPLine::kItemVelocity, kTrackInfoSliderHeight, kTrackInfoSliderExtra,
         VelocitySliderDrawFunction },
-#endif
    } );
 } } noteTrackTCPLines;
 
-void NoteTrackControls::GetVelocityRect(const wxPoint &topleft, wxRect & dest)
+void NoteTrackControls::GetVelocityRect(const wxRect &rect_, wxRect & dest)
 {
-   TrackInfo::GetSliderHorizontalBounds( topleft, dest );
-   auto results = CalcItemY( noteTrackTCPLines, TCPLine::kItemVelocity );
-   dest.y = topleft.y + results.first;
+   const auto rect = wxRect(rect_).Deflate(CommonTrackInfo::Margin);
+   CommonTrackInfo::GetSliderHorizontalBounds( rect, dest );
+   const auto results = CalcItemY( noteTrackTCPLines, TCPLine::kItemVelocity );
+   dest.y = rect.y + results.first;
    dest.height = results.second;
 }
 
-void NoteTrackControls::GetMidiControlsRect(const wxRect & rect, wxRect & dest)
+void NoteTrackControls::GetMidiControlsRect(const wxRect & rect_, wxRect & dest)
 {
+   const auto rect = wxRect(rect_).Deflate(CommonTrackInfo::Margin);
    GetMidiControlsHorizontalBounds( rect, dest );
-   auto results = TrackInfo::CalcItemY(
+   const auto results = TrackInfo::CalcItemY(
       noteTrackTCPLines, TCPLine::kItemMidiControlsRect );
    dest.y = rect.y + results.first;
    dest.height = results.second;
@@ -252,7 +335,7 @@ void NoteTrackControls::GetMidiControlsRect(const wxRect & rect, wxRect & dest)
 
 unsigned NoteTrackControls::DefaultNoteTrackHeight()
 {
-   return TrackInfo::DefaultTrackHeight( noteTrackTCPLines );
+   return CommonTrackInfo::DefaultTrackHeight( noteTrackTCPLines );
 }
 
 const TCPLines &NoteTrackControls::GetTCPLines() const
@@ -262,16 +345,13 @@ const TCPLines &NoteTrackControls::GetTCPLines() const
 
 namespace {
 
-#ifdef EXPERIMENTAL_MIDI_OUT
    std::unique_ptr<LWSlider>
      gVelocityCaptured
    , gVelocity
    ;
-#endif
 
 }
 
-#ifdef EXPERIMENTAL_MIDI_OUT
 LWSlider * NoteTrackControls::VelocitySlider
 (const wxRect &sliderRect, const NoteTrack *t, bool captured, wxWindow *pParent)
 {
@@ -291,16 +371,13 @@ LWSlider * NoteTrackControls::VelocitySlider
    slider->SetParent( pParent );
    return slider;
 }
-#endif
 
 void NoteTrackControls::ReCreateVelocitySlider(ThemeChangeMessage message)
 {
    if (message.appearance)
       return;
-#ifdef EXPERIMENTAL_MIDI_OUT
-   wxPoint point{ 0, 0 };
-   wxRect sliderRect;
-   GetVelocityRect(point, sliderRect);
+
+   const auto sliderRect = wxRect(0, 0, kTrackInfoSliderWidth, kTrackInfoSliderHeight);
 
    /* i18n-hint: Title of the Velocity slider, used to adjust the volume of note tracks */
    gVelocity = std::make_unique<LWSlider>(nullptr, XO("Velocity"),
@@ -313,7 +390,6 @@ void NoteTrackControls::ReCreateVelocitySlider(ThemeChangeMessage message)
       wxSize(sliderRect.width, sliderRect.height),
       VEL_SLIDER);
    gVelocityCaptured->SetDefaultValue(0.0);
-#endif
 }
 
 using DoGetNoteTrackControls = DoGetControls::Override< NoteTrack >;
