@@ -10,31 +10,24 @@ Paul Licameli split from TrackMenus.cpp
 **********************************************************************/
 
 #include "CommonCommandFlags.h"
+#include "CommandContext.h"
 #include "ProjectHistory.h"
-#include "ProjectWindow.h"
+
 #include "SelectUtilities.h"
 #include "TimeTrack.h"
-#include "TrackPanelAx.h"
-#include "../../../commands/CommandContext.h"
-#include "../../../commands/CommandManager.h"
+#include "TrackFocus.h"
+#include "Viewport.h"
+#include "CommandContext.h"
+#include "MenuRegistry.h"
 #include "AudacityMessageBox.h"
 
 namespace {
-using namespace MenuTable;
+using namespace MenuRegistry;
 
 void OnNewTimeTrack(const CommandContext &context)
 {
    auto &project = context.project;
    auto &tracks = TrackList::Get( project );
-   auto &window = ProjectWindow::Get( project );
-   
-
-   if (*tracks.Any<TimeTrack>().begin()) {
-      AudacityMessageBox(
-         XO(
-"This version of Audacity only allows one time track for each project window.") );
-      return;
-   }
 
    auto t = tracks.AddToHead(std::make_shared<TimeTrack>());
 
@@ -46,13 +39,24 @@ void OnNewTimeTrack(const CommandContext &context)
       .PushState(XO("Created new time track"), XO("New Track"));
 
    TrackFocus::Get(project).Set(t);
-   t->EnsureVisible();
+   Viewport::Get(project).ShowTrack(*t);
 }
 
-AttachedItem sAttachment{ wxT("Tracks/Add/Add"),
-     Command( wxT("NewTimeTrack"), XXO("&Time Track"),
-        OnNewTimeTrack, AudioIONotBusyFlag()
- )
+const ReservedCommandFlag &TimeTrackDoesNotExistFlag()
+{
+   static ReservedCommandFlag flag{
+      [](const AudacityProject &project){
+         return TrackList::Get(project).Any<const TimeTrack>().empty();
+      }
+   };
+   return flag;
+}
+
+AttachedItem sAttachment{
+   Command( wxT("NewTimeTrack"), XXO("&Time Track"),
+        OnNewTimeTrack, AudioIONotBusyFlag() | TimeTrackDoesNotExistFlag()
+   ),
+   wxT("Tracks/Add/Add")
 };
 
 }
