@@ -16,8 +16,8 @@ Paul Licameli split from TrackPanel.cpp
 
 #include "AColor.h"
 #include "CommandManager.h"
-#include "../../SpectrumAnalyst.h"
-#include "../../LabelTrack.h"
+#include "SpectrumAnalyst.h"
+#include "LabelTrack.h"
 #include "../playabletrack/wavetrack/ui/PitchAndSpeedDialog.h"
 #include "NumberScale.h"
 #include "Project.h"
@@ -39,7 +39,7 @@ Paul Licameli split from TrackPanel.cpp
 #include "WaveChannelUtilities.h"
 #include "WaveClip.h"
 #include "WaveTrack.h"
-#include "../../prefs/SpectrogramSettings.h"
+#include "SpectrogramSettings.h"
 #include "../../../images/Cursors.h"
 
 // Only for definition of SonifyBeginModifyState:
