@@ -13,7 +13,7 @@ Paul Licameli split from TrackPanel.cpp
 
 #include "../../UIHandle.h"
 #include "SelectedRegion.h"
-#include "../../Snap.h"
+#include "Snap.h"
 
 #include <vector>
 
@@ -21,9 +21,11 @@ class SelectionStateChanger;
 class SnapManager;
 class SpectrumAnalyst;
 class Track;
-class TrackView;
+class Channel;
+class ChannelView;
 class TrackList;
 class ViewInfo;
+class WaveChannel;
 class WaveTrack;
 class wxMouseState;
 
@@ -32,23 +34,25 @@ class AUDACITY_DLL_API SelectHandle : public UIHandle
    SelectHandle(const SelectHandle&);
 
 public:
-   explicit SelectHandle
-      (const std::shared_ptr<TrackView> &pTrackView, bool useSnap,
-       const TrackList &trackList,
-       const TrackPanelMouseState &st, const ViewInfo &viewInfo);
+   SelectHandle(
+      const std::shared_ptr<ChannelView> &pChannelView, bool useSnap,
+      const TrackList &trackList,
+      const TrackPanelMouseState &st, const ViewInfo &viewInfo);
 
    // This always hits, but details of the hit vary with mouse position and
    // key state.
-   static UIHandlePtr HitTest
-      (std::weak_ptr<SelectHandle> &holder,
-       const TrackPanelMouseState &state, const AudacityProject *pProject,
-       const std::shared_ptr<TrackView> &pTrackView);
+   static UIHandlePtr HitTest(
+      std::weak_ptr<SelectHandle> &holder,
+      const TrackPanelMouseState &state, const AudacityProject *pProject,
+      const std::shared_ptr<ChannelView> &pChannelView);
 
    SelectHandle &operator=(const SelectHandle&) = default;
    
    virtual ~SelectHandle();
 
-   bool IsClicked() const;
+   std::shared_ptr<const Track> FindTrack() const override;
+
+   bool IsDragging() const override;
 
    void SetUseSnap(bool use, AudacityProject *pProject);
    void Enter(bool forward, AudacityProject *pProject) override;
@@ -79,40 +83,39 @@ public:
        const SelectHandle &newState);
 
 private:
-   std::weak_ptr<Track> FindTrack();
+   std::shared_ptr<Channel> FindChannel();
+   static Track *FindTrack(Channel *);
+   Track *FindTrack();
 
    void Connect(AudacityProject *pProject);
 
    void StartSelection(AudacityProject *pProject);
-   void AdjustSelection
-      (AudacityProject *pProject,
-       ViewInfo &viewInfo, int mouseXCoordinate, int trackLeftEdge,
-       Track *pTrack);
-   void AssignSelection(ViewInfo &viewInfo, double selend, Track *pTrack);
+   void AdjustSelection(
+      AudacityProject *pProject,
+      ViewInfo &viewInfo, int mouseXCoordinate, int trackLeftEdge,
+      Track *pTrack);
+   void AssignSelection(ViewInfo &viewInfo, double selend);
 
-   void StartFreqSelection
-      (ViewInfo &viewInfo, int mouseYCoordinate, int trackTopEdge,
-      int trackHeight, TrackView *pTrackView);
-   void AdjustFreqSelection
-      (const WaveTrack *wt,
-       ViewInfo &viewInfo, int mouseYCoordinate, int trackTopEdge,
-       int trackHeight);
+   void StartFreqSelection(
+      ViewInfo &viewInfo, int mouseYCoordinate, int trackTopEdge,
+      int trackHeight, ChannelView &channelView);
+   void AdjustFreqSelection(const WaveChannel &wc,
+      ViewInfo &viewInfo, int mouseYCoordinate, int trackTopEdge,
+      int trackHeight);
 
-   void HandleCenterFrequencyClick
-      (const ViewInfo &viewInfo, bool shiftDown,
-       const WaveTrack *pTrack, double value);
-   static void StartSnappingFreqSelection
-      (SpectrumAnalyst &analyst,
-       const ViewInfo &viewInfo, const WaveTrack *pTrack);
-   void MoveSnappingFreqSelection
-      (AudacityProject *pProject, ViewInfo &viewInfo, int mouseYCoordinate,
-       int trackTopEdge,
-       int trackHeight, TrackView *pTrackView);
+   void HandleCenterFrequencyClick(
+      const ViewInfo &viewInfo, bool shiftDown,
+      const std::shared_ptr<const WaveChannel> &pWc, double value);
+   static void StartSnappingFreqSelection(SpectrumAnalyst &analyst,
+      const ViewInfo &viewInfo, const WaveChannel &wc);
+   void MoveSnappingFreqSelection(
+      AudacityProject *pProject, ViewInfo &viewInfo, int mouseYCoordinate,
+      int trackTopEdge,
+      int trackHeight, ChannelView &channelView, Track *pTrack);
 public:
    // This is needed to implement a command assignable to keystrokes
-   static void SnapCenterOnce
-      (SpectrumAnalyst &analyst,
-       ViewInfo &viewInfo, const WaveTrack *pTrack, bool up);
+   static void SnapCenterOnce(SpectrumAnalyst &analyst,
+      ViewInfo &viewInfo, const WaveChannel &wc, bool up);
 private:
 
    // TrackPanelDrawable implementation
@@ -128,7 +131,7 @@ private:
    //   (const ViewInfo &viewInfo, double hintFrequency, bool logF);
 
 
-   std::weak_ptr<TrackView> mpView;
+   std::weak_ptr<ChannelView> mpView;
    wxRect mRect{};
    SelectedRegion mInitialSelection{};
 
@@ -152,7 +155,7 @@ private:
       FREQ_SEL_TOP_FREE,
       FREQ_SEL_BOTTOM_FREE,
    }  mFreqSelMode{ FREQ_SEL_INVALID };
-   std::weak_ptr<const WaveTrack> mFreqSelTrack;
+   std::weak_ptr<const WaveChannel> mFreqSelTrack;
    // Following holds:
    // the center for FREQ_SEL_PINNED_CENTER,
    // the ratio of top to center (== center to bottom) for FREQ_SEL_DRAG_CENTER,
